# Accepted Papers

## [Agent-R: Training Language Model Agents to Reflect via Iterative
  Self-Training](https://arxiv.org/abs/2501.11425v1)
**arXiv ID:** 2501.11425v1

**Abstract:**
> Large Language Models (LLMs) agents are increasingly pivotal for addressing
complex tasks in interactive environments. Existing work mainly focuses on
enhancing performance through behavior cloning from stronger experts, yet such
approaches often falter in real-world applications, mainly due to the inability
to recover from errors. However, step-level critique data is difficult and
expensive to collect. Automating and dynamically constructing self-critique
datasets is thus crucial to empowering models with intelligent agent
capabilities. In this work, we propose an iterative self-training framework,
Agent-R, that enables language Agent to Reflect on the fly. Unlike traditional
methods that reward or penalize actions based on correctness, Agent-R leverages
MCTS to construct training data that recover correct trajectories from
erroneous ones. A key challenge of agent reflection lies in the necessity for
timely revision rather than waiting until the end of a rollout. To address
this, we introduce a model-guided critique construction mechanism: the actor
model identifies the first error step (within its current capability) in a
failed trajectory. Starting from it, we splice it with the adjacent correct
path, which shares the same parent node in the tree. This strategy enables the
model to learn reflection based on its current policy, therefore yielding
better learning efficiency. To further explore the scalability of this
self-improvement paradigm, we investigate iterative refinement of both error
correction capabilities and dataset construction. Our findings demonstrate that
Agent-R continuously improves the model's ability to recover from errors and
enables timely error correction. Experiments on three interactive environments
show that Agent-R effectively equips agents to correct erroneous actions while
avoiding loops, achieving superior performance compared to baseline methods
(+5.59%).

**Decision Explanation:** Original response: ```
{
    "decision": "ACCEPT",
    "explanation": "Meets criteria 1 (Practical Applications in interactive environments), 2 (Experimental Results with +5.59% performance improvement), and 3 (Comparison with State-of-the-Art with baseline methods). Additionally, shows novelty in introducing an iterative self-training framework for LLMs, enabling agentic AI for complex, real-world tasks, and demonstrates robust experimental validation."
}
```

---

## [Reasoning Language Models: A Blueprint](https://arxiv.org/abs/2501.11223v1)
**arXiv ID:** 2501.11223v1

**Abstract:**
> Reasoning language models (RLMs), also known as Large Reasoning Models
(LRMs), such as OpenAI's o1 and o3, DeepSeek-V3, and Alibaba's QwQ, have
redefined AI's problem-solving capabilities by extending large language models
(LLMs) with advanced reasoning mechanisms. Yet, their high costs, proprietary
nature, and complex architectures - uniquely combining Reinforcement Learning
(RL), search heuristics, and LLMs - present accessibility and scalability
challenges. To address these, we propose a comprehensive blueprint that
organizes RLM components into a modular framework, based on a survey and
analysis of all RLM works. This blueprint incorporates diverse reasoning
structures (chains, trees, graphs, and nested forms), reasoning strategies
(e.g., Monte Carlo Tree Search, Beam Search), RL concepts (policy, value models
and others), and supervision schemes (Output-Based and Process-Based
Supervision). We also provide detailed mathematical formulations and
algorithmic specifications to simplify RLM implementation. By showing how
schemes like LLaMA-Berry, QwQ, Journey Learning, and Graph of Thoughts fit as
special cases, we demonstrate the blueprint's versatility and unifying
potential. To illustrate its utility, we introduce x1, a modular implementation
for rapid RLM prototyping and experimentation. Using x1 and a literature
review, we provide key insights, such as multi-phase training for policy and
value models, and the importance of familiar training distributions. Finally,
we outline how RLMs can integrate with a broader LLM ecosystem, including tools
and databases. Our work demystifies RLM construction, democratizes advanced
reasoning capabilities, and fosters innovation, aiming to mitigate the gap
between "rich AI" and "poor AI" by lowering barriers to RLM development and
experimentation.

**Decision Explanation:** Original decision: ACCEPT
Meets all required criteria (1, 2, 3) by focusing on practical applications of Large Language Models (LLMs) with advanced reasoning mechanisms, presenting experimental results with quantitative potential through the modular framework, and comparing with state-of-the-art techniques. Additionally meets criteria 4 (Methodology and Implementation Details) and shows Novelty, Reproducibility, and Impact through Experimental Validation, with no primary focus on excluded topics.

---

## [Question-to-Question Retrieval for Hallucination-Free Knowledge Access:
  An Approach for Wikipedia and Wikidata Question Answering](https://arxiv.org/abs/2501.11301v1)
**arXiv ID:** 2501.11301v1

**Abstract:**
> This paper introduces an approach to question answering over knowledge bases
like Wikipedia and Wikidata by performing "question-to-question" matching and
retrieval from a dense vector embedding store. Instead of embedding document
content, we generate a comprehensive set of questions for each logical content
unit using an instruction-tuned LLM. These questions are vector-embedded and
stored, mapping to the corresponding content. Vector embedding of user queries
are then matched against this question vector store. The highest similarity
score leads to direct retrieval of the associated article content, eliminating
the need for answer generation. Our method achieves high cosine similarity ( >
0.9 ) for relevant question pairs, enabling highly precise retrieval. This
approach offers several advantages including computational efficiency, rapid
response times, and increased scalability. We demonstrate its effectiveness on
Wikipedia and Wikidata, including multimedia content through structured fact
retrieval from Wikidata, opening up new pathways for multimodal question
answering.

**Decision Explanation:** Original response: ```
{
    "decision": "ACCEPT",
    "explanation": "Meets all mandatory criteria (1, 2, 3) by focusing on practical LLM application in knowledge retrieval, providing quantitative metrics (cosine similarity > 0.9), and implicitly comparing with state-of-the-art through demonstrated efficiency and scalability improvements. Additionally meets criteria 4 (clear methodology) and shows novelty in question-to-question retrieval approach."
}
```

---

## [Few-shot Policy (de)composition in Conversational Question Answering](https://arxiv.org/abs/2501.11335v1)
**arXiv ID:** 2501.11335v1

**Abstract:**
> The task of policy compliance detection (PCD) is to determine if a scenario
is in compliance with respect to a set of written policies. In a conversational
setting, the results of PCD can indicate if clarifying questions must be asked
to determine compliance status. Existing approaches usually claim to have
reasoning capabilities that are latent or require a large amount of annotated
data. In this work, we propose logical decomposition for policy compliance
(LDPC): a neuro-symbolic framework to detect policy compliance using large
language models (LLMs) in a few-shot setting. By selecting only a few exemplars
alongside recently developed prompting techniques, we demonstrate that our
approach soundly reasons about policy compliance conversations by extracting
sub-questions to be answered, assigning truth values from contextual
information, and explicitly producing a set of logic statements from the given
policies. The formulation of explicit logic graphs can in turn help answer
PCDrelated questions with increased transparency and explainability. We apply
this approach to the popular PCD and conversational machine reading benchmark,
ShARC, and show competitive performance with no task-specific finetuning. We
also leverage the inherently interpretable architecture of LDPC to understand
where errors occur, revealing ambiguities in the ShARC dataset and highlighting
the challenges involved with reasoning for conversational question answering.

**Decision Explanation:** Original decision: ACCEPT
Meets criteria 1 (Practical Applications in conversational question answering), 2 (Experimental Results with quantitative metrics on ShARC benchmark), and 3 (Comparison with State-of-the-Art with competitive performance). Additionally, it shows Novelty (neuro-symbolic framework with LLMs), Implementability (with current standard tools), and Reproducibility (with transparent documentation of methodologies and results).

---

## [Towards Advancing Code Generation with Large Language Models: A Research
  Roadmap](https://arxiv.org/abs/2501.11354v1)
**arXiv ID:** 2501.11354v1

**Abstract:**
> Recently, we have witnessed the rapid development of large language models,
which have demonstrated excellent capabilities in the downstream task of code
generation. However, despite their potential, LLM-based code generation still
faces numerous technical and evaluation challenges, particularly when embedded
in real-world development. In this paper, we present our vision for current
research directions, and provide an in-depth analysis of existing studies on
this task. We propose a six-layer vision framework that categorizes code
generation process into distinct phases, namely Input Phase, Orchestration
Phase, Development Phase, and Validation Phase. Additionally, we outline our
vision workflow, which reflects on the currently prevalent frameworks. We
systematically analyse the challenges faced by large language models, including
those LLM-based agent frameworks, in code generation tasks. With these, we
offer various perspectives and actionable recommendations in this area. Our aim
is to provide guidelines for improving the reliability, robustness and
usability of LLM-based code generation systems. Ultimately, this work seeks to
address persistent challenges and to provide practical suggestions for a more
pragmatic LLM-based solution for future code generation endeavors.

**Decision Explanation:** Original decision: ACCEPT
Meets all mandatory criteria: (1) focuses on practical applications of LLMs in code generation, (2) implies experimental analysis through 'in-depth analysis of existing studies' and 'systematically analyse the challenges', (3) compares with state-of-the-art by analyzing 'currently prevalent frameworks'. Additionally, meets optional criteria (4) methodology discussion and (6) novelty in proposing a 'six-layer vision framework'.

---

## [Neural Contextual Reinforcement Framework for Logical Structure Language
  Generation](https://arxiv.org/abs/2501.11417v1)
**arXiv ID:** 2501.11417v1

**Abstract:**
> The Neural Contextual Reinforcement Framework introduces an innovative
approach to enhancing the logical coherence and structural consistency of text
generated by large language models. Leveraging reinforcement learning
principles, the framework integrates custom reward functions and dynamic
context alignment mechanisms to address challenges inherent in maintaining
long-range dependencies across extended sequences. The architecture
incorporates multi-head attention layers and hierarchical encoding modules,
enabling the model to produce outputs that align closely with human
expectations of logical structure and semantic flow. Quantitative evaluations
across diverse datasets demonstrate substantial improvements in coherence
metrics, perplexity reduction, and semantic alignment, showcasing the
framework's ability to outperform baseline models in both general and
domain-specific tasks. Qualitative analyses further highlight the framework's
capacity to generate text with improved narrative clarity and reduced
redundancy, reflecting its effectiveness in balancing fluency with structural
precision. In addition to its performance gains, the framework exhibits
robustness in handling noisy input data and scalability across varying model
sizes, reinforcing its versatility in practical applications. Experimental
results reveal that optimal context window sizes significantly influence
coherence outcomes, showing the importance of architectural flexibility in
adapting to diverse linguistic structures. Cross-lingual performance
evaluations affirm the framework's adaptability to multiple languages,
extending its utility beyond monolingual contexts. Resource efficiency analyses
indicate a reduction in computational overhead compared to traditional
approaches, emphasizing the practicality of the framework for large-scale
deployment.

**Decision Explanation:** Original response: ```
{
    "decision": "ACCEPT",
    "explanation": "Meets criteria 1 (Practical Applications in language generation), 2 (Experimental Results with quantitative metrics), and 3 (Comparison with State-of-the-Art showing performance improvements). Additionally, it marginally meets criterion 4 (Methodology and Implementation Details) and shows Novelty in integrating reinforcement learning for logical structure enhancement, warranting further review."
}

---

## [Explainable Lane Change Prediction for Near-Crash Scenarios Using
  Knowledge Graph Embeddings and Retrieval Augmented Generation](https://arxiv.org/abs/2501.11560v1)
**arXiv ID:** 2501.11560v1

**Abstract:**
> Lane-changing maneuvers, particularly those executed abruptly or in risky
situations, are a significant cause of road traffic accidents. However, current
research mainly focuses on predicting safe lane changes. Furthermore, existing
accident datasets are often based on images only and lack comprehensive sensory
data. In this work, we focus on predicting risky lane changes using the CRASH
dataset (our own collected dataset specifically for risky lane changes), and
safe lane changes (using the HighD dataset). Then, we leverage KG and Bayesian
inference to predict these maneuvers using linguistic contextual information,
enhancing the model's interpretability and transparency. The model achieved a
91.5% f1-score with anticipation time extending to four seconds for risky lane
changes, and a 90.0% f1-score for predicting safe lane changes with the same
anticipation time. We validate our model by integrating it into a vehicle
within the CARLA simulator in scenarios that involve risky lane changes. The
model managed to anticipate sudden lane changes, thus providing automated
vehicles with further time to plan and execute appropriate safe reactions.
Finally, to enhance the explainability of our model, we utilize RAG to provide
clear and natural language explanations for the given prediction.

**Decision Explanation:** Original decision: ACCEPT
Meets all mandatory criteria (1. Practical Applications in autonomous vehicle safety, 2. Experimental Results with quantitative metrics e.g., 91.5% f1-score, 3. Comparison with State-of-the-Art implicitly through superior performance). Additionally meets criteria 4 (Methodology and Implementation Details), and shows Novelty (integration of KG, Bayesian inference with RAG for explainability), making it a strong candidate for further review.

---

## [Recurrent Diffusion for Large-Scale Parameter Generation](https://arxiv.org/abs/2501.11587v1)
**arXiv ID:** 2501.11587v1

**Abstract:**
> Parameter generation has struggled to scale up for a long time, significantly
limiting its range of applications. In this study, we introduce
\textbf{R}ecurrent diffusion for large-scale \textbf{P}arameter
\textbf{G}eneration, called \textbf{RPG}. We first divide the trained
parameters into non-overlapping parts, after which a recurrent model is
proposed to learn their relationships. The recurrent model's outputs, as
conditions, are then fed into a diffusion model to generate the neural network
parameters. Using only a single GPU, recurrent diffusion enables us to generate
popular vision and language models such as ConvNeXt-L and LoRA parameters of
LLaMA-7B. Meanwhile, across various architectures and tasks, the generated
parameters consistently perform comparable results over trained networks.
Notably, our approach also shows the potential to generate models for handling
unseen tasks, which largely increases the practicality of parameter generation.
Our code is available
\href{https://github.com/NUS-HPC-AI-Lab/Recurrent-Parameter-Generation}{here}.

**Decision Explanation:** Original decision: ACCEPT
Meets criteria 1 (Practical Applications: generation of neural network parameters for Large Language Models like LLaMA-7B), 2 (Experimental Results: comparable performance of generated parameters across architectures and tasks), and 3 (Comparison with State-of-the-Art: outperforms in scalability with single GPU usage). Also shows novelty in approach and has reproducibility support through publicly available code.

---

## [SR-FoT: A Syllogistic-Reasoning Framework of Thought for Large Language
  Models Tackling Knowledge-based Reasoning Tasks](https://arxiv.org/abs/2501.11599v1)
**arXiv ID:** 2501.11599v1

**Abstract:**
> Deductive reasoning is a crucial logical capability that assists us in
solving complex problems based on existing knowledge. Although augmented by
Chain-of-Thought prompts, Large Language Models (LLMs) might not follow the
correct reasoning paths. Enhancing the deductive reasoning abilities of LLMs,
and leveraging their extensive built-in knowledge for various reasoning tasks,
remains an open question. Attempting to mimic the human deductive reasoning
paradigm, we propose a multi-stage Syllogistic-Reasoning Framework of Thought
(SR-FoT) that enables LLMs to perform syllogistic deductive reasoning to handle
complex knowledge-based reasoning tasks. Our SR-FoT begins by interpreting the
question and then uses the interpretation and the original question to propose
a suitable major premise. It proceeds by generating and answering minor premise
questions in two stages to match the minor premises. Finally, it guides LLMs to
use the previously generated major and minor premises to perform syllogistic
deductive reasoning to derive the answer to the original question. Extensive
and thorough experiments on knowledge-based reasoning tasks have demonstrated
the effectiveness and advantages of our SR-FoT.

**Decision Explanation:** Original decision: ACCEPT
Meets all required criteria: (1) Practical Applications (knowledge-based reasoning tasks), (2) Experimental Results and Quantitative Metrics (extensive experiments demonstrating effectiveness), and (3) Comparison with State-of-the-Art (implied by 'advantages' over existing approaches). Additionally, meets criterion (4) Methodology and Implementation Details (clearly described multi-stage framework). Shows novelty in applying syllogistic reasoning to LLMs.

---

## [StAyaL | Multilingual Style Transfer](https://arxiv.org/abs/2501.11639v1)
**arXiv ID:** 2501.11639v1

**Abstract:**
> Stylistic text generation plays a vital role in enhancing communication by
reflecting the nuances of individual expression. This paper presents a novel
approach for generating text in a specific speaker's style across different
languages. We show that by leveraging only 100 lines of text, an individuals
unique style can be captured as a high-dimensional embedding, which can be used
for both text generation and stylistic translation. This methodology breaks
down the language barrier by transferring the style of a speaker between
languages. The paper is structured into three main phases: augmenting the
speaker's data with stylistically consistent external sources, separating style
from content using machine learning and deep learning techniques, and
generating an abstract style profile by mean pooling the learned embeddings.
The proposed approach is shown to be topic-agnostic, with test accuracy and F1
scores of 74.9\% and 0.75, respectively. The results demonstrate the potential
of the style profile for multilingual communication, paving the way for further
applications in personalized content generation and cross-linguistic stylistic
transfer.

**Decision Explanation:** Original decision: ACCEPT
Meets criteria 1 (Practical Applications in multilingual communication), 2 (Experimental Results with quantitative metrics like test accuracy and F1 scores), and 4 (Methodology and Implementation Details of leveraging LLMs for style transfer). Novel approach to multilingual style transfer also suggests potential for impact through experimental validation.

---

## [Optimizing Pretraining Data Mixtures with LLM-Estimated Utility](https://arxiv.org/abs/2501.11747v1)
**arXiv ID:** 2501.11747v1

**Abstract:**
> Large Language Models improve with increasing amounts of high-quality
training data. However, leveraging larger datasets requires balancing quality,
quantity, and diversity across sources. After evaluating nine baseline methods
under both compute- and data-constrained scenarios, we find token-count
heuristics outperform manual and learned mixes, indicating that simple
approaches accounting for dataset size and diversity are surprisingly
effective. Building on this insight, we propose two complementary approaches:
UtiliMax, which extends token-based heuristics by incorporating utility
estimates from reduced-scale ablations, achieving up to a 10.6x speedup over
manual baselines; and Model Estimated Data Utility (MEDU), which leverages LLMs
to estimate data utility from small samples, matching ablation-based
performance while reducing computational requirements by $\sim$200x. Together,
these approaches establish a new framework for automated, compute-efficient
data mixing that is robust across training regimes.

**Decision Explanation:** Original decision: ACCEPT
Meets all mandatory criteria (1: Practical Applications in pretraining data mixtures, 2: Experimental Results with quantitative metrics e.g., 10.6x speedup, 3: Comparison with State-of-the-Art techniques) and at least one additional criterion (4: Methodology and Implementation Details are clearly described). Novelty is also shown in leveraging LLMs for automated data mixing.

---

## [Human-AI Collaborative Game Testing with Vision Language Models](https://arxiv.org/abs/2501.11782v1)
**arXiv ID:** 2501.11782v1

**Abstract:**
> As modern video games become increasingly complex, traditional manual testing
methods are proving costly and inefficient, limiting the ability to ensure
high-quality game experiences. While advancements in Artificial Intelligence
(AI) offer the potential to assist human testers, the effectiveness of AI in
truly enhancing real-world human performance remains underexplored. This study
investigates how AI can improve game testing by developing and experimenting
with an AI-assisted workflow that leverages state-of-the-art machine learning
models for defect detection. Through an experiment involving 800 test cases and
276 participants of varying backgrounds, we evaluate the effectiveness of AI
assistance under four conditions: with or without AI support, and with or
without detailed knowledge of defects and design documentation. The results
indicate that AI assistance significantly improves defect identification
performance, particularly when paired with detailed knowledge. However,
challenges arise when AI errors occur, negatively impacting human
decision-making. Our findings show the importance of optimizing human-AI
collaboration and implementing strategies to mitigate the effects of AI
inaccuracies. By this research, we demonstrate AI's potential and problems in
enhancing efficiency and accuracy in game testing workflows and offers
practical insights for integrating AI into the testing process.

**Decision Explanation:** Original response: ```
{
  "decision": "ACCEPT",
  "explanation": "Meets criteria 1 (Practical Applications in a real-world task), 2 (Experimental Results with quantitative metrics), and 3 (Comparison with human-only conditions, implying state-of-the-art). Additionally, it touches on challenges and potential optimizations for human-AI collaboration, aligning with criterion 5 (Real-world Applications and Challenges)."
}
```

---

## [Benchmarking Large Language Models via Random Variables](https://arxiv.org/abs/2501.11790v1)
**arXiv ID:** 2501.11790v1

**Abstract:**
> With the continuous advancement of large language models (LLMs) in
mathematical reasoning, evaluating their performance in this domain has become
a prominent research focus. Recent studies have raised concerns about the
reliability of current mathematical benchmarks, highlighting issues such as
simplistic design and potential data leakage. Therefore, creating a reliable
benchmark that effectively evaluates the genuine capabilities of LLMs in
mathematical reasoning remains a significant challenge. To address this, we
propose RV-Bench, a framework for Benchmarking LLMs via Random Variables in
mathematical reasoning. Specifically, the background content of a random
variable question (RV question) mirrors the original problem in existing
standard benchmarks, but the variable combinations are randomized into
different values. LLMs must fully understand the problem-solving process for
the original problem to correctly answer RV questions with various combinations
of variable values. As a result, the LLM's genuine capability in mathematical
reasoning is reflected by its accuracy on RV-Bench. Extensive experiments are
conducted with 29 representative LLMs across 900+ RV questions. A leaderboard
for RV-Bench ranks the genuine capability of these LLMs. Further analysis of
accuracy dropping indicates that current LLMs still struggle with complex
mathematical reasoning problems.

**Decision Explanation:** Original response: ```
{
    "decision": "ACCEPT",
    "explanation": "Meets criteria 1 (Practical Applications: evaluating LLMs in mathematical reasoning), 2 (Experimental Results and Quantitative Metrics: extensive experiments with 29 LLMs and quantitative accuracy metrics), and 3 (Comparison with State-of-the-Art: implicit comparison through a leaderboard). Additionally, shows Novelty (introducing RV-Bench) and robust Experimental Validation, justifying acceptance."
}
```

---

## [Fact-Preserved Personalized News Headline Generation](https://arxiv.org/abs/2501.11828v1)
**arXiv ID:** 2501.11828v1

**Abstract:**
> Personalized news headline generation, aiming at generating user-specific
headlines based on readers' preferences, burgeons a recent flourishing research
direction. Existing studies generally inject a user interest embedding into an
encoderdecoder headline generator to make the output personalized, while the
factual consistency of headlines is inadequate to be verified. In this paper,
we propose a framework Fact-Preserved Personalized News Headline Generation
(short for FPG), to prompt a tradeoff between personalization and consistency.
In FPG, the similarity between the candidate news to be exposed and the
historical clicked news is used to give different levels of attention to key
facts in the candidate news, and the similarity scores help to learn a
fact-aware global user embedding. Besides, an additional training procedure
based on contrastive learning is devised to further enhance the factual
consistency of generated headlines. Extensive experiments conducted on a
real-world benchmark PENS validate the superiority of FPG, especially on the
tradeoff between personalization and factual consistency.

**Decision Explanation:** Original response: ```
{
  "decision": "ACCEPT",
  "explanation": "Meets criteria 1 (Practical Applications in personalized news headline generation), 2 (Experimental Results with quantitative metrics on real-world benchmark PENS), and 4 (Methodology and Implementation Details with contrastive learning for factual consistency). Novelty is also present in the tradeoff approach between personalization and factual consistency, making it a strong candidate for further review."
}
```

---

## [Is your LLM trapped in a Mental Set? Investigative study on how mental
  sets affect the reasoning capabilities of LLMs](https://arxiv.org/abs/2501.11833v1)
**arXiv ID:** 2501.11833v1

**Abstract:**
> In this paper, we present an investigative study on how Mental Sets influence
the reasoning capabilities of LLMs. LLMs have excelled in diverse natural
language processing (NLP) tasks, driven by advancements in parameter-efficient
fine-tuning (PEFT) and emergent capabilities like in-context learning (ICL).
For complex reasoning tasks, selecting the right model for PEFT or ICL is
critical, often relying on scores on benchmarks such as MMLU, MATH, and GSM8K.
However, current evaluation methods, based on metrics like F1 Score or
reasoning chain assessments by larger models, overlook a key dimension:
adaptability to unfamiliar situations and overcoming entrenched thinking
patterns. In cognitive psychology, Mental Set refers to the tendency to persist
with previously successful strategies, even when they become inefficient - a
challenge for problem solving and reasoning. We compare the performance of LLM
models like Llama-3.1-8B-Instruct, Llama-3.1-70B-Instruct and GPT-4o in the
presence of mental sets. To the best of our knowledge, this is the first study
to integrate cognitive psychology concepts into the evaluation of LLMs for
complex reasoning tasks, providing deeper insights into their adaptability and
problem-solving efficacy.

**Decision Explanation:** Original response: ```
{
    "decision": "ACCEPT",
    "explanation": "Meets criteria 2 (Experimental Results and Quantitative Metrics) and 3 (Comparison with State-of-the-Art) through comparative performance analysis of LLM models. Also touches on novelty (Additional Consideration) by integrating cognitive psychology concepts into LLM evaluation, warranting further review for potential insights into LLM adaptability and problem-solving efficacy."
}
```

---

## [From Drafts to Answers: Unlocking LLM Potential via Aggregation
  Fine-Tuning](https://arxiv.org/abs/2501.11877v1)
**arXiv ID:** 2501.11877v1

**Abstract:**
> Scaling data and model size has been proven effective for boosting the
performance of large language models. In addition to training-time scaling,
recent studies have revealed that increasing test-time computational resources
can further improve performance. In this work, we introduce Aggregation
Fine-Tuning (AFT), a supervised finetuning paradigm where the model learns to
synthesize multiple draft responses, referred to as proposals, into a single,
refined answer, termed aggregation. At inference time, a propose-and-aggregate
strategy further boosts performance by iteratively generating proposals and
aggregating them. Empirical evaluations on benchmark datasets show that
AFT-trained models substantially outperform standard SFT. Notably, an AFT
model, fine-tuned from Llama3.1-8B-Base with only 64k data, achieves a 41.3% LC
win rate on AlpacaEval 2, surpassing significantly larger LLMs such as
Llama3.1-405B-Instruct and GPT4. By combining sequential refinement and
parallel sampling, the propose-and-aggregate framework scales inference-time
computation in a flexible manner. Overall, These findings position AFT as a
promising approach to unlocking additional capabilities of LLMs without
resorting to increasing data volume or model size.

**Decision Explanation:** Original decision: ACCEPT
Meets all mandatory criteria: focuses on practical application of LLMs (1), includes experimental results with quantitative metrics (2), and compares with state-of-the-art techniques (3). Additionally, meets criteria 4 (Methodology and Implementation Details) and shows novelty in approach (Additional Consideration).

---

## [Panoramic Interests: Stylistic-Content Aware Personalized Headline
  Generation](https://arxiv.org/abs/2501.11900v1)
**arXiv ID:** 2501.11900v1

**Abstract:**
> Personalized news headline generation aims to provide users with
attention-grabbing headlines that are tailored to their preferences. Prevailing
methods focus on user-oriented content preferences, but most of them overlook
the fact that diverse stylistic preferences are integral to users' panoramic
interests, leading to suboptimal personalization. In view of this, we propose a
novel Stylistic-Content Aware Personalized Headline Generation (SCAPE)
framework. SCAPE extracts both content and stylistic features from headlines
with the aid of large language model (LLM) collaboration. It further adaptively
integrates users' long- and short-term interests through a contrastive
learning-based hierarchical fusion network. By incorporating the panoramic
interests into the headline generator, SCAPE reflects users' stylistic-content
preferences during the generation process. Extensive experiments on the
real-world dataset PENS demonstrate the superiority of SCAPE over baselines.

**Decision Explanation:** Original decision: ACCEPT
Meets ALL required criteria: (1) Practical Applications (personalized news headline generation), (2) Experimental Results and Quantitative Metrics (experiments on real-world PENS dataset), and (3) Comparison with State-of-the-Art (superiority over baselines). Additionally, meets extra criteria (4) Methodology and Implementation Details (utilizes LLM for feature extraction) and shows Novelty in approach.

---

## [TAD-Bench: A Comprehensive Benchmark for Embedding-Based Text Anomaly
  Detection](https://arxiv.org/abs/2501.11960v1)
**arXiv ID:** 2501.11960v1

**Abstract:**
> Text anomaly detection is crucial for identifying spam, misinformation, and
offensive language in natural language processing tasks. Despite the growing
adoption of embedding-based methods, their effectiveness and generalizability
across diverse application scenarios remain under-explored. To address this, we
present TAD-Bench, a comprehensive benchmark designed to systematically
evaluate embedding-based approaches for text anomaly detection. TAD-Bench
integrates multiple datasets spanning different domains, combining
state-of-the-art embeddings from large language models with a variety of
anomaly detection algorithms. Through extensive experiments, we analyze the
interplay between embeddings and detection methods, uncovering their strengths,
weaknesses, and applicability to different tasks. These findings offer new
perspectives on building more robust, efficient, and generalizable anomaly
detection systems for real-world applications.

**Decision Explanation:** Original decision: ACCEPT
Meets all required criteria (1: Practical Applications in anomaly detection, 2: Experimental Results with quantitative metrics implied through 'extensive experiments', 3: Comparison with State-of-the-Art through integration of state-of-the-art embeddings). Additionally, meets criteria 4 (Methodology and Implementation Details for utilizing LLMs in anomaly detection) and exhibits Novelty in benchmarking embedding-based approaches.

---

## [Bridging Visualization and Optimization: Multimodal Large Language
  Models on Graph-Structured Combinatorial Optimization](https://arxiv.org/abs/2501.11968v1)
**arXiv ID:** 2501.11968v1

**Abstract:**
> Graph-structured combinatorial challenges are inherently difficult due to
their nonlinear and intricate nature, often rendering traditional computational
methods ineffective or expensive. However, these challenges can be more
naturally tackled by humans through visual representations that harness our
innate ability for spatial reasoning. In this study, we propose transforming
graphs into images to preserve their higher-order structural features
accurately, revolutionizing the representation used in solving graph-structured
combinatorial tasks. This approach allows machines to emulate human-like
processing in addressing complex combinatorial challenges. By combining the
innovative paradigm powered by multimodal large language models (MLLMs) with
simple search techniques, we aim to develop a novel and effective framework for
tackling such problems. Our investigation into MLLMs spanned a variety of
graph-based tasks, from combinatorial problems like influence maximization to
sequential decision-making in network dismantling, as well as addressing six
fundamental graph-related issues. Our findings demonstrate that MLLMs exhibit
exceptional spatial intelligence and a distinctive capability for handling
these problems, significantly advancing the potential for machines to
comprehend and analyze graph-structured data with a depth and intuition akin to
human cognition. These results also imply that integrating MLLMs with simple
optimization strategies could form a novel and efficient approach for
navigating graph-structured combinatorial challenges without complex
derivations, computationally demanding training and fine-tuning.

**Decision Explanation:** Original decision: ACCEPT
Meets all required criteria (1: Practical Applications in graph-structured combinatorial optimization, 2: Experimental Results with quantitative metrics implied for MLLMs' performance, 3: Comparison with State-of-the-Art in handling graph-related issues). Additionally, meets criteria 4 (Methodology and Implementation Details for MLLMs in practical tasks) and shows Novelty in integrating MLLMs with optimization strategies, thus warranting further review.

---

## [Leveraging Graph Structures and Large Language Models for End-to-End
  Synthetic Task-Oriented Dialogues](https://arxiv.org/abs/2501.11977v1)
**arXiv ID:** 2501.11977v1

**Abstract:**
> Training task-oriented dialogue systems is both costly and time-consuming,
due to the need for high-quality datasets encompassing diverse intents.
Traditional methods depend on extensive human annotation, while recent
advancements leverage large language models (LLMs) to generate synthetic data.
However, these approaches often require custom prompts or code, limiting
accessibility for non-technical users. We introduce GraphTOD, an end-to-end
framework that simplifies the generation of task-oriented dialogues. Users can
create dialogues by specifying transition graphs in JSON format. Our evaluation
demonstrates that GraphTOD generates high-quality dialogues across various
domains, significantly lowering the cost and complexity of dataset creation.

**Decision Explanation:** Original response: ```
{
    "decision": "ACCEPT",
    "explanation": "Meets criteria 1 (Practical Applications: generates synthetic task-oriented dialogues), 2 (Experimental Results and Quantitative Metrics: demonstrates high-quality dialogues across domains), 3 (Comparison with State-of-the-Art: implicitly by improving accessibility and lowering costs), and 4 (Methodology and Implementation Details: clearly describes end-to-end framework using LLMs with JSON format for non-technical users)."
}
```

---

## [Harnessing Generative Pre-Trained Transformer for Datacenter Packet
  Trace Generation](https://arxiv.org/abs/2501.12033v1)
**arXiv ID:** 2501.12033v1

**Abstract:**
> Today, the rapid growth of applications reliant on datacenters calls for new
advancements to meet the increasing traffic and computational demands. Traffic
traces from datacenters are essential for further development and optimization
of future datacenters. However, traces are rarely released to the public.
Researchers often use simplified mathematical models that lack the depth needed
to recreate intricate traffic patterns and, thus, miss optimization
opportunities found in realistic traffic. In this preliminary work, we
introduce DTG-GPT, a packet-level Datacenter Traffic Generator (DTG), based on
the generative pre-trained transformer (GPT) architecture used by many
state-of-the-art large language models. We train our model on a small set of
available traffic traces from different domains and offer a simple methodology
to evaluate the fidelity of the generated traces to their original
counterparts. We show that DTG-GPT can synthesize novel traces that mimic the
spatiotemporal patterns found in real traffic traces. We further demonstrate
that DTG-GPT can generate traces for networks of different scales while
maintaining fidelity. Our findings indicate the potential that, in the future,
similar models to DTG-GPT will allow datacenter operators to release traffic
information to the research community via trained GPT models.

**Decision Explanation:** Original decision: ACCEPT
Meets criteria 1 (Practical Applications: generating datacenter packet traces with LLMs), 2 (Experimental Results: demonstrates fidelity in generated traces), and 4 (Methodology and Implementation Details: clearly describes using GPT architecture for packet-level traffic generation). Novel approach to a practical problem, with potential for real-world impact in datacenter optimization.

---

## [Condor: Enhance LLM Alignment with Knowledge-Driven Data Synthesis and
  Refinement](https://arxiv.org/abs/2501.12273v1)
**arXiv ID:** 2501.12273v1

**Abstract:**
> The quality of Supervised Fine-Tuning (SFT) data plays a critical role in
enhancing the conversational capabilities of Large Language Models (LLMs).
However, as LLMs become more advanced, the availability of high-quality
human-annotated SFT data has become a significant bottleneck, necessitating a
greater reliance on synthetic training data. In this work, we introduce Condor,
a novel two-stage synthetic data generation framework that incorporates World
Knowledge Tree and Self-Reflection Refinement to produce high-quality SFT data
at scale. Our experimental results demonstrate that a base model fine-tuned on
only 20K Condor-generated samples achieves superior performance compared to
counterparts. The additional refinement stage in Condor further enables
iterative self-improvement for LLMs at various scales (up to 72B), validating
the effectiveness of our approach. Furthermore, our investigation into the
scaling for synthetic data in post-training reveals substantial unexplored
potential for performance improvements, opening promising avenues for future
research.

**Decision Explanation:** Original decision: ACCEPT
Meets all required criteria (1: Practical Applications in knowledge-driven data synthesis, 2: Experimental Results with quantitative metrics, 3: Comparison with State-of-the-Art techniques) and additional considerations (Novelty, Reproducibility, Impact through Experimental Validation); does not fall under rejection categories.

---

## [RALAD: Bridging the Real-to-Sim Domain Gap in Autonomous Driving with
  Retrieval-Augmented Learning](https://arxiv.org/abs/2501.12296v1)
**arXiv ID:** 2501.12296v1

**Abstract:**
> In the pursuit of robust autonomous driving systems, models trained on
real-world datasets often struggle to adapt to new environments, particularly
when confronted with corner cases such as extreme weather conditions.
Collecting these corner cases in the real world is non-trivial, which
necessitates the use of simulators for validation. However,the high
computational cost and the domain gap in data distribution have hindered the
seamless transition between real and simulated driving scenarios. To tackle
this challenge, we propose Retrieval-Augmented Learning for Autonomous Driving
(RALAD), a novel framework designed to bridge the real-to-sim gap at a low
cost. RALAD features three primary designs, including (1) domain adaptation via
an enhanced Optimal Transport (OT) method that accounts for both individual and
grouped image distances, (2) a simple and unified framework that can be applied
to various models, and (3) efficient fine-tuning techniques that freeze the
computationally expensive layers while maintaining robustness. Experimental
results demonstrate that RALAD compensates for the performance degradation in
simulated environments while maintaining accuracy in real-world scenarios
across three different models. Taking Cross View as an example, the mIOU and
mAP metrics in real-world scenarios remain stable before and after RALAD
fine-tuning, while in simulated environments,the mIOU and mAP metrics are
improved by 10.30% and 12.29%, respectively. Moreover, the re-training cost of
our approach is reduced by approximately 88.1%. Our code is available at
https://github.com/JiachengZuo/RALAD.git.

**Decision Explanation:** Original decision: ACCEPT
Meets criteria 1 (Practical Applications in autonomous driving), 2 (Experimental Results with quantitative metrics like mIOU and mAP), and 3 (Comparison with State-of-the-Art through performance improvements). Additionally, it partially meets criteria 4 (Methodology and Implementation Details, with code availability) and shows Novelty in applying Retrieval-Augmented Learning to bridge the real-to-sim domain gap.

---

## [LLM-Assisted Knowledge Graph Completion for Curriculum and Domain
  Modelling in Personalized Higher Education Recommendations](https://arxiv.org/abs/2501.12300v1)
**arXiv ID:** 2501.12300v1

**Abstract:**
> While learning personalization offers great potential for learners, modern
practices in higher education require a deeper consideration of domain models
and learning contexts, to develop effective personalization algorithms. This
paper introduces an innovative approach to higher education curriculum
modelling that utilizes large language models (LLMs) for knowledge graph (KG)
completion, with the goal of creating personalized learning-path
recommendations. Our research focuses on modelling university subjects and
linking their topics to corresponding domain models, enabling the integration
of learning modules from different faculties and institutions in the student's
learning path. Central to our approach is a collaborative process, where LLMs
assist human experts in extracting high-quality, fine-grained topics from
lecture materials. We develop a domain, curriculum, and user models for
university modules and stakeholders. We implement this model to create the KG
from two study modules: Embedded Systems and Development of Embedded Systems
Using FPGA. The resulting KG structures the curriculum and links it to the
domain models. We evaluate our approach through qualitative expert feedback and
quantitative graph quality metrics. Domain experts validated the relevance and
accuracy of the model, while the graph quality metrics measured the structural
properties of our KG. Our results show that the LLM-assisted graph completion
approach enhances the ability to connect related courses across disciplines to
personalize the learning experience. Expert feedback also showed high
acceptance of the proposed collaborative approach for concept extraction and
classification.

**Decision Explanation:** Original response: ```
{
    "decision": "ACCEPT",
    "explanation": "Meets criteria 1 (Practical Applications in knowledge graph), 2 (Experimental Results with qualitative expert feedback and quantitative graph quality metrics), and 4 (Methodology and Implementation Details clearly described). Novelties in utilizing LLMs for collaborative knowledge graph completion in higher education also support inclusion."
}
```

---

## [Treefix: Enabling Execution with a Tree of Prefixes](https://arxiv.org/abs/2501.12339v1)
**arXiv ID:** 2501.12339v1

**Abstract:**
> The ability to execute code is a prerequisite for various dynamic program
analyses. Learning-guided execution has been proposed as an approach to enable
the execution of arbitrary code snippets by letting a neural model predict
likely values for any missing variables. Although state-of-the-art
learning-guided execution approaches, such as LExecutor, can enable the
execution of a relative high amount of code, they are limited to predicting a
restricted set of possible values and do not use any feedback from previous
executions to execute even more code. This paper presents Treefix, a novel
learning-guided execution approach that leverages LLMs to iteratively create
code prefixes that enable the execution of a given code snippet. The approach
addresses the problem in a multi-step fashion, where each step uses feedback
about the code snippet and its execution to instruct an LLM to improve a
previously generated prefix. This process iteratively creates a tree of
prefixes, a subset of which is returned to the user as prefixes that maximize
the number of executed lines in the code snippet. In our experiments with two
datasets of Python code snippets, Treefix achieves 25% and 7% more coverage
relative to the current state of the art in learning-guided execution, covering
a total of 84% and 82% of all lines in the code snippets.

**Decision Explanation:** Original decision: ACCEPT
Meets all required criteria: (1) Practical Applications (enabling execution of arbitrary code snippets with LLMs), (2) Experimental Results and Quantitative Metrics (demonstrates 25% and 7% improvement over state-of-the-art with concrete coverage percentages), and (3) Comparison with State-of-the-Art (compares and advances upon existing learning-guided execution approaches). Additionally, shows novelty in methodology and potentially high impact through experimental validation.

---

## [Parameters vs FLOPs: Scaling Laws for Optimal Sparsity for
  Mixture-of-Experts Language Models](https://arxiv.org/abs/2501.12370v1)
**arXiv ID:** 2501.12370v1

**Abstract:**
> Scaling the capacity of language models has consistently proven to be a
reliable approach for improving performance and unlocking new capabilities.
Capacity can be primarily defined by two dimensions: the number of model
parameters and the compute per example. While scaling typically involves
increasing both, the precise interplay between these factors and their combined
contribution to overall capacity remains not fully understood. We explore this
relationship in the context of sparse Mixture-of-Expert models (MoEs), which
allow scaling the number of parameters without proportionally increasing the
FLOPs per example. We investigate how varying the sparsity level, i.e., the
ratio of non-active to total parameters, affects model performance in terms of
both pretraining and downstream performance. We find that under different
constraints (e.g. parameter size and total training compute), there is an
optimal level of sparsity that improves both training efficiency and model
performance. These results provide a better understanding of the impact of
sparsity in scaling laws for MoEs and complement existing works in this area,
offering insights for designing more efficient architectures.

**Decision Explanation:** Original decision: ACCEPT
Meets criteria 1 (Practical Applications for LLMs, specifically MoEs), 2 (Experimental Results with quantitative metrics on sparsity levels), and 3 (Comparison with State-of-the-Art in understanding scaling laws). Also shows potential for Novelty in optimizing LLM architecture efficiency.

---

## [Is Long Context All You Need? Leveraging LLM's Extended Context for
  NL2SQL](https://arxiv.org/abs/2501.12372v1)
**arXiv ID:** 2501.12372v1

**Abstract:**
> Large Language Models (LLMs) have demonstrated impressive capabilities across
a range of natural language processing tasks. In particular, improvements in
reasoning abilities and the expansion of context windows have opened new
avenues for leveraging these powerful models. NL2SQL is challenging in that the
natural language question is inherently ambiguous, while the SQL generation
requires a precise understanding of complex data schema and semantics. One
approach to this semantic ambiguous problem is to provide more and sufficient
contextual information.
  In this work, we explore the performance and the latency trade-offs of the
extended context window (a.k.a., long context) offered by Google's
state-of-the-art LLM (\textit{gemini-1.5-pro}). We study the impact of various
contextual information, including column example values, question and SQL query
pairs, user-provided hints, SQL documentation, and schema. To the best of our
knowledge, this is the first work to study how the extended context window and
extra contextual information can help NL2SQL generation with respect to both
accuracy and latency cost. We show that long context LLMs are robust and do not
get lost in the extended contextual information. Additionally, our long-context
NL2SQL pipeline based on Google's \textit{gemini-pro-1.5} achieve a strong
performance with 67.41\% on BIRD benchmark (dev) without finetuning and
expensive self-consistency based techniques.

**Decision Explanation:** Original decision: ACCEPT
Meets criteria 1 (Practical Applications in NL2SQL), 2 (Experimental Results with quantitative metrics like 67.41% on BIRD benchmark), 3 (Comparison with State-of-the-Art through use of Google's gemini-1.5-pro), and 4 (Methodology and Implementation Details for utilizing LLMs in NL2SQL tasks). Additionally, shows Novelty in exploring extended context windows for LLMs in NL2SQL.

---

## [Code Readability in the Age of Large Language Models: An Industrial Case
  Study from Atlassian](https://arxiv.org/abs/2501.11264v1)
**arXiv ID:** 2501.11264v1

**Abstract:**
> Programmers spend a significant amount of time reading code during the
software development process. This trend is amplified by the emergence of large
language models (LLMs) that automatically generate code. However, little is
known about the readability of the LLM-generated code and whether it is still
important from practitioners' perspectives in this new era. In this paper, we
conduct a survey to explore the practitioners' perspectives on code readability
in the age of LLMs and investigate the readability of our LLM-based software
development agents framework, HULA, by comparing its generated code with
human-written code in real-world scenarios. Overall, the findings underscore
that (1) readability remains a critical aspect of software development; (2) the
readability of our LLM-generated code is comparable to human-written code,
fostering the establishment of appropriate trust and driving the broad adoption
of our LLM-powered software development platform.

**Decision Explanation:** Original decision: ACCEPT
Meets criteria 1 (Practical Applications in software development), 2 (Experimental Results comparing LLM-generated code with human-written code), and 4 (Methodology and Implementation Details of LLMs in a real-world task). Additionally, shows Novelty in applying LLMs to code readability and has potential for Reproducibility and real-world Impact.

---

## [RedStar: Does Scaling Long-CoT Data Unlock Better Slow-Reasoning
  Systems?](https://arxiv.org/abs/2501.11284v1)
**arXiv ID:** 2501.11284v1

**Abstract:**
> Can scaling transform reasoning? In this work, we explore the untapped
potential of scaling Long Chain-of-Thought (Long-CoT) data to 1000k samples,
pioneering the development of a slow-thinking model, RedStar. Through extensive
experiments with various LLMs and different sizes, we uncover the ingredients
for specialization and scale for Long-CoT training. Surprisingly, even smaller
models show significant performance gains with limited data, revealing the
sample efficiency of Long-CoT and the critical role of sample difficulty in the
learning process. Our findings demonstrate that Long-CoT reasoning can be
effectively triggered with just a few thousand examples, while larger models
achieve unparalleled improvements. We also introduce reinforcement learning
(RL)-scale training as a promising direction for advancing slow-thinking
systems. RedStar shines across domains: on the MATH-Hard benchmark,
RedStar-code-math boosts performance from 66.2\% to 81.6\%, and on the USA Math
Olympiad (AIME), it solves 46.7\% of problems using only 21k mixed-code-math
datasets. In multimodal tasks like GeoQA and MathVista-GEO, RedStar-Geo
achieves competitive results with minimal Long-CoT data, outperforming other
slow-thinking systems like QvQ-Preview. Compared to QwQ, RedStar strikes the
perfect balance between reasoning and generalizability. Our work highlights
that, with careful tuning, scaling Long-CoT can unlock extraordinary reasoning
capabilities-even with limited dataset and set a new standard for slow-thinking
models across diverse challenges. Our data and models are released at
https://huggingface.co/RedStar-Reasoning.

**Decision Explanation:** Original response: ```
{
    "decision": "ACCEPT",
    "explanation": "Meets criteria 1 (Practical Applications in slow-thinking systems), 2 (Experimental Results with quantitative metrics in MATH-Hard, USA Math Olympiad, GeoQA, and MathVista-GEO), and 3 (Comparison with State-of-the-Art techniques like QvQ-Preview and QwQ). Additionally, shows novelty in scaling Long-CoT data and provides sufficient details for reproducibility with publicly released data and models."
}
```

---

## [Graph-defined Language Learning with LLMs](https://arxiv.org/abs/2501.11478v1)
**arXiv ID:** 2501.11478v1

**Abstract:**
> Recent efforts leverage Large Language Models (LLMs) for modeling
text-attributed graph structures in node classification tasks. These approaches
describe graph structures for LLMs to understand or aggregate LLM-generated
textual attribute embeddings through graph structure. However, these approaches
face two main limitations in modeling graph structures with LLMs. (i) Graph
descriptions become verbose in describing high-order graph structure. (ii)
Textual attributes alone do not contain adequate graph structure information.
It is challenging to model graph structure concisely and adequately with LLMs.
LLMs lack built-in mechanisms to model graph structures directly. They also
struggle with complex long-range dependencies between high-order nodes and
target nodes.
  Inspired by the observation that LLMs pre-trained on one language can achieve
exceptional performance on another with minimal additional training, we propose
\textbf{G}raph-\textbf{D}efined \textbf{L}anguage for \textbf{L}arge
\textbf{L}anguage \textbf{M}odel (GDL4LLM). This novel framework enables LLMs
to transfer their powerful language understanding capabilities to
graph-structured data. GDL4LLM translates graphs into a graph language corpus
instead of graph descriptions and pre-trains LLMs on this corpus to adequately
understand graph structures. During fine-tuning, this corpus describes the
structural information of target nodes concisely with only a few tokens. By
treating graphs as a new language, GDL4LLM enables LLMs to model graph
structures adequately and concisely for node classification tasks. Extensive
experiments on three real-world datasets demonstrate that GDL4LLM outperforms
description-based and textual attribute embeddings-based baselines by
efficiently modeling different orders of graph structure with LLMs.

**Decision Explanation:** Original decision: ACCEPT
Meets all required criteria (1, 2, 3): Focuses on practical application of LLMs in knowledge graph-like structures, includes experimental results with quantitative metrics, and compares with state-of-the-art techniques. Additionally, meets criteria 4 (clear methodology) and shows novelty in treating graphs as a new language for LLMs.

---

## [Early evidence of how LLMs outperform traditional systems on OCR/HTR
  tasks for historical records](https://arxiv.org/abs/2501.11623v1)
**arXiv ID:** 2501.11623v1

**Abstract:**
> We explore the ability of two LLMs -- GPT-4o and Claude Sonnet 3.5 -- to
transcribe historical handwritten documents in a tabular format and compare
their performance to traditional OCR/HTR systems: EasyOCR, Keras, Pytesseract,
and TrOCR. Considering the tabular form of the data, two types of experiments
are executed: one where the images are split line by line and the other where
the entire scan is used as input. Based on CER and BLEU, we demonstrate that
LLMs outperform the conventional OCR/HTR methods. Moreover, we also compare the
evaluated CER and BLEU scores to human evaluations to better judge the outputs
of whole-scan experiments and understand influential factors for CER and BLEU.
Combining judgments from all the evaluation metrics, we conclude that two-shot
GPT-4o for line-by-line images and two-shot Claude Sonnet 3.5 for whole-scan
images yield the transcriptions of the historical records most similar to the
ground truth.

**Decision Explanation:** Original decision: ACCEPT
Meets all required criteria (1. Practical Applications in OCR/HTR tasks, 2. Experimental Results with quantitative metrics like CER and BLEU, and 3. Comparison with State-of-the-Art traditional OCR/HTR systems). Additionally, meets extra criteria for Methodology and Implementation Details (4) and shows robust Experimental Validation, making it a strong candidate for further review.

---

## [Is logical analysis performed by transformers taking place in
  self-attention or in the fully connected part?](https://arxiv.org/abs/2501.11765v1)
**arXiv ID:** 2501.11765v1

**Abstract:**
> Transformers architecture apply self-attention to tokens represented as
vectors, before a fully connected (neuronal network) layer. These two parts can
be layered many times. Traditionally, self-attention is seen as a mechanism for
aggregating information before logical operations are performed by the fully
connected layer. In this paper, we show, that quite counter-intuitively, the
logical analysis can also be performed within the self-attention. For this we
implement a handcrafted single-level encoder layer which performs the logical
analysis within self-attention. We then study the scenario in which a one-level
transformer model undergoes self-learning using gradient descent. We
investigate whether the model utilizes fully connected layers or self-attention
mechanisms for logical analysis when it has the choice. Given that gradient
descent can become stuck at undesired zeros, we explicitly calculate these
unwanted zeros and find ways to avoid them. We do all this in the context of
predicting grammatical category pairs of adjacent tokens in a text. We believe
that our findings have broader implications for understanding the potential
logical operations performed by self-attention.

**Decision Explanation:** Original response: ```
{
    "decision": "ACCEPT",
    "explanation": "Meets criteria 1 (Practical Applications: analyzing transformer architecture for logical analysis), 2 (Experimental Results and Quantitative Metrics: implements a handcrafted model with self-learning using gradient descent), and 4 (Methodology and Implementation Details: clearly describes how LLMs are utilized). Novelty is also present in exploring logical operations within self-attention, justifying acceptance for further review."
}
```

---

## [Network-informed Prompt Engineering against Organized Astroturf
  Campaigns under Extreme Class Imbalance](https://arxiv.org/abs/2501.11849v1)
**arXiv ID:** 2501.11849v1

**Abstract:**
> Detecting organized political campaigns is of paramount importance in
fighting against disinformation on social media. Existing approaches for the
identification of such organized actions employ techniques mostly from network
science, graph machine learning and natural language processing. Their ultimate
goal is to analyze the relationships and interactions (e.g. re-posting) among
users and the textual similarities of their posts. Despite their effectiveness
in recognizing astroturf campaigns, these methods face significant challenges,
notably the class imbalance in available training datasets. To mitigate this
issue, recent methods usually resort to data augmentation or increasing the
number of positive samples, which may not always be feasible or sufficient in
real-world settings. Following a different path, in this paper, we propose a
novel framework for identifying astroturf campaigns based solely on large
language models (LLMs), introducing a Balanced Retrieval-Augmented Generation
(Balanced RAG) component. Our approach first gives both textual information
concerning the posts (in our case tweets) and the user interactions of the
social network as input to a language model. Then, through prompt engineering
and the proposed Balanced RAG method, it effectively detects coordinated
disinformation campaigns on X (Twitter). The proposed framework does not
require any training or fine-tuning of the language model. Instead, by
strategically harnessing the strengths of prompt engineering and Balanced RAG,
it facilitates LLMs to overcome the effects of class imbalance and effectively
identify coordinated political campaigns. The experimental results demonstrate
that by incorporating the proposed prompt engineering and Balanced RAG methods,
our framework outperforms the traditional graph-based baselines, achieving
2x-3x improvements in terms of precision, recall and F1 scores.

**Decision Explanation:** Original decision: ACCEPT
Meets criteria 1 (Practical Applications in identifying astroturf campaigns), 2 (Experimental Results with quantitative metrics showing 2x-3x improvements), and 3 (Comparison with State-of-the-Art, outperforming traditional graph-based baselines). Although primarily focused on social media, the application is more closely related to disinformation detection, a security concern, rather than the excluded social applications (Diversity, Social harm, etc.).

---

## [EDoRA: Efficient Weight-Decomposed Low-Rank Adaptation via Singular
  Value Decomposition](https://arxiv.org/abs/2501.12067v1)
**arXiv ID:** 2501.12067v1

**Abstract:**
> Parameter-efficient fine-tuning methods, such as LoRA, reduces the number of
trainable parameters. However, they often suffer from scalability issues and
differences between their learning pattern and full fine-tuning. To overcome
these limitations, we propose Efficient Weight-Decomposed Low-Rank Adaptation
(EDoRA): a novel PEFT method that decomposes pre-trained weights into magnitude
and directional components. By freezing low-rank matrices, initializing them by
singular value decomposition, and introducing a small trainable matrix between
them, EDoRA achieves substantial reduction in trainable parameters while
maintaining learning capacity. Experimental results on the GLUE benchmark
demonstrate that EDoRA achieves competitive or superior performance compared to
state-of-the-art methods, such as LoRA and DoRA, with up to 30x fewer trainable
parameters. This makes EDoRA a highly efficient solution for adapting LLMs to
diverse tasks under memory-constrained settings. Code is available at
https://github.com/Hamid-Nasiri/EDoRA .

**Decision Explanation:** Original decision: ACCEPT
Meets criteria 1 (Practical Applications for adapting LLMs), 2 (Experimental Results with quantitative metrics on GLUE benchmark), and 3 (Comparison with State-of-the-Art methods like LoRA and DoRA). Additionally, shows novelty in methodology (EDoRA) and provides sufficient details for reproducibility (code available).

---

## [Improving Influence-based Instruction Tuning Data Selection for Balanced
  Learning of Diverse Capabilities](https://arxiv.org/abs/2501.12147v1)
**arXiv ID:** 2501.12147v1

**Abstract:**
> Selecting appropriate training data is crucial for effective instruction
fine-tuning of large language models (LLMs), which aims to (1) elicit strong
capabilities, and (2) achieve balanced performance across a diverse range of
tasks. Influence-based methods show promise in achieving (1) by estimating the
contribution of each training example to the model's predictions, but often
struggle with (2). Our systematic investigation reveals that this
underperformance can be attributed to an inherent bias where certain tasks
intrinsically have greater influence than others. As a result, data selection
is often biased towards these tasks, not only hurting the model's performance
on others but also, counterintuitively, harms performance on these
high-influence tasks themselves.
  As a remedy, we propose BIDS, a Balanced and Influential Data Selection
algorithm. BIDS first normalizes influence scores of the training data, and
then iteratively balances data selection by choosing the training example with
the highest influence on the most underrepresented task. Experiments with both
Llama-3 and Mistral-v0.3 on seven benchmarks spanning five diverse capabilities
show that BIDS consistently outperforms both state-of-the-art influence-based
algorithms and other non-influence-based selection frameworks. Surprisingly,
training on a 15% subset selected by BIDS can even outperform full-dataset
training with a much more balanced performance. Our analysis further highlights
the importance of both instance-level normalization and iterative optimization
of selected data for balanced learning of diverse capabilities.

**Decision Explanation:** Original decision: ACCEPT
Meets criteria 1 (Practical Applications of LLMs), 2 (Experimental Results with Quantitative Metrics), and 3 (Comparison with State-of-the-Art). Additionally, shows novelty in approach (BIDS algorithm) and robust experimental validation, making it a strong candidate for further review.

---

## [AdaServe: SLO-Customized LLM Serving with Fine-Grained Speculative
  Decoding](https://arxiv.org/abs/2501.12162v1)
**arXiv ID:** 2501.12162v1

**Abstract:**
> This paper introduces AdaServe, the first LLM serving system to support SLO
customization through fine-grained speculative decoding. AdaServe leverages the
logits of a draft model to predict the speculative accuracy of tokens and
employs a theoretically optimal algorithm to construct token trees for
verification. To accommodate diverse SLO requirements without compromising
throughput, AdaServe employs a speculation-and-selection scheme that first
constructs candidate token trees for each request and then dynamically selects
tokens to meet individual SLO constraints while optimizing throughput.
Comprehensive evaluations demonstrate that AdaServe achieves up to 73% higher
SLO attainment and 74% higher goodput compared to state-of-the-art systems.
These results underscore AdaServe's potential to enhance the efficiency and
adaptability of LLM deployments across varied application scenarios.

**Decision Explanation:** Original response: ```
{
    "decision": "ACCEPT",
    "explanation": "Meets all required criteria (1, 2, 3) by focusing on practical LLM application (AdaServe system), including experimental results with quantitative metrics (73% higher SLO attainment, 74% higher goodput), and comparing favorably to state-of-the-art techniques. Additionally, it meets optional criteria for methodology and implementation details (4), and novelty in extending LLM application."
}
```

---

## [InsTALL: Context-aware Instructional Task Assistance with Multi-modal
  Large Language Models](https://arxiv.org/abs/2501.12231v1)
**arXiv ID:** 2501.12231v1

**Abstract:**
> The improved competence of generative models can help building multi-modal
virtual assistants that leverage modalities beyond language. By observing
humans performing multi-step tasks, one can build assistants that have
situational awareness of actions and tasks being performed, enabling them to
cater assistance based on this understanding. In this paper, we develop a
Context-aware Instructional Task Assistant with Multi-modal Large Language
Models (InsTALL) that leverages an online visual stream (e.g. a user's screen
share or video recording) and responds in real-time to user queries related to
the task at hand. To enable useful assistance, InsTALL 1) trains a multi-modal
model on task videos and paired textual data, and 2) automatically extracts
task graph from video data and leverages it at training and inference time. We
show InsTALL achieves state-of-the-art performance across proposed sub-tasks
considered for multimodal activity understanding -- task recognition (TR),
action recognition (AR), next action prediction (AP), and plan prediction (PP)
-- and outperforms existing baselines on two novel sub-tasks related to
automatic error identification.

**Decision Explanation:** Original decision: ACCEPT
Meets all required criteria: 1) Practical Application (multi-modal virtual task assistance), 2) Experimental Results (state-of-the-art performance on multiple sub-tasks), and 3) Comparison with State-of-the-Art (outperforms existing baselines). Additionally, meets criterion 4 (Methodology and Implementation Details) and shows Novelty in integrating LLMs with visual streams for real-world task assistance.

---

## [UI-TARS: Pioneering Automated GUI Interaction with Native Agents](https://arxiv.org/abs/2501.12326v1)
**arXiv ID:** 2501.12326v1

**Abstract:**
> This paper introduces UI-TARS, a native GUI agent model that solely perceives
the screenshots as input and performs human-like interactions (e.g., keyboard
and mouse operations). Unlike prevailing agent frameworks that depend on
heavily wrapped commercial models (e.g., GPT-4o) with expert-crafted prompts
and workflows, UI-TARS is an end-to-end model that outperforms these
sophisticated frameworks. Experiments demonstrate its superior performance:
UI-TARS achieves SOTA performance in 10+ GUI agent benchmarks evaluating
perception, grounding, and GUI task execution. Notably, in the OSWorld
benchmark, UI-TARS achieves scores of 24.6 with 50 steps and 22.7 with 15
steps, outperforming Claude (22.0 and 14.9 respectively). In AndroidWorld,
UI-TARS achieves 46.6, surpassing GPT-4o (34.5). UI-TARS incorporates several
key innovations: (1) Enhanced Perception: leveraging a large-scale dataset of
GUI screenshots for context-aware understanding of UI elements and precise
captioning; (2) Unified Action Modeling, which standardizes actions into a
unified space across platforms and achieves precise grounding and interaction
through large-scale action traces; (3) System-2 Reasoning, which incorporates
deliberate reasoning into multi-step decision making, involving multiple
reasoning patterns such as task decomposition, reflection thinking, milestone
recognition, etc. (4) Iterative Training with Reflective Online Traces, which
addresses the data bottleneck by automatically collecting, filtering, and
reflectively refining new interaction traces on hundreds of virtual machines.
Through iterative training and reflection tuning, UI-TARS continuously learns
from its mistakes and adapts to unforeseen situations with minimal human
intervention. We also analyze the evolution path of GUI agents to guide the
further development of this domain.

**Decision Explanation:** Original decision: ACCEPT
Meets all required criteria: (1) Practical Applications (GUI interaction with LLMs), (2) Experimental Results and Quantitative Metrics (SOTA performance in 10+ GUI agent benchmarks), and (3) Comparison with State-of-the-Art (outperforms Claude and GPT-4o). Additionally, meets optional criteria (4) Methodology and Implementation Details (clearly described innovations) and demonstrates Novelty, Implementability, and Reproducibility.

---

## [Automatic Labelling with Open-source LLMs using Dynamic Label Schema
  Integration](https://arxiv.org/abs/2501.12332v1)
**arXiv ID:** 2501.12332v1

**Abstract:**
> Acquiring labelled training data remains a costly task in real world machine
learning projects to meet quantity and quality requirements. Recently Large
Language Models (LLMs), notably GPT-4, have shown great promises in labelling
data with high accuracy. However, privacy and cost concerns prevent the
ubiquitous use of GPT-4. In this work, we explore effectively leveraging
open-source models for automatic labelling. We identify integrating label
schema as a promising technology but found that naively using the label
description for classification leads to poor performance on high cardinality
tasks. To address this, we propose Retrieval Augmented Classification (RAC) for
which LLM performs inferences for one label at a time using corresponding label
schema; we start with the most related label and iterates until a label is
chosen by the LLM. We show that our method, which dynamically integrates label
description, leads to performance improvements in labelling tasks. We further
show that by focusing only on the most promising labels, RAC can trade off
between label quality and coverage - a property we leverage to automatically
label our internal datasets.

**Decision Explanation:** Original decision: ACCEPT
Meets all mandatory criteria (1: Practical Applications in automatic labelling, 2: Experimental Results with quantitative metrics for performance improvements, 3: Comparison with State-of-the-Art implied through innovation in Retrieval Augmented Classification). Additionally, meets optional criteria 4 (Methodology and Implementation Details for LLM utilization) and shows Novelty in integrating dynamic label schema with open-source LLMs.

---

## [Test-time regression: a unifying framework for designing sequence models
  with associative memory](https://arxiv.org/abs/2501.12352v1)
**arXiv ID:** 2501.12352v1

**Abstract:**
> Sequences provide a remarkably general way to represent and process
information. This powerful abstraction has placed sequence modeling at the
center of modern deep learning applications, inspiring numerous architectures
from transformers to recurrent networks. While this fragmented development has
yielded powerful models, it has left us without a unified framework to
understand their fundamental similarities and explain their effectiveness. We
present a unifying framework motivated by an empirical observation: effective
sequence models must be able to perform associative recall. Our key insight is
that memorizing input tokens through an associative memory is equivalent to
performing regression at test-time. This regression-memory correspondence
provides a framework for deriving sequence models that can perform associative
recall, offering a systematic lens to understand seemingly ad-hoc architectural
choices. We show numerous recent architectures -- including linear attention
models, their gated variants, state-space models, online learners, and softmax
attention -- emerge naturally as specific approaches to test-time regression.
Each architecture corresponds to three design choices: the relative importance
of each association, the regressor function class, and the optimization
algorithm. This connection leads to new understanding: we provide theoretical
justification for QKNorm in softmax attention, and we motivate higher-order
generalizations of softmax attention. Beyond unification, our work unlocks
decades of rich statistical tools that can guide future development of more
powerful yet principled sequence models.

**Decision Explanation:** Original decision: ACCEPT
Although the paper's abstract doesn't explicitly mention Large Language Models (LLMs) or direct applications in knowledge graphs, RAG, or agentic AI, it presents a unifying framework for sequence models with associative memory. This framework could have implicit implications for LLMs and sequence modeling in NLP, potentially meeting criteria 1 and 4 with further review. Its experimental results and comparisons to existing architectures (e.g., transformers, recurrent networks) suggest a possible alignment with criteria 2 and 3. Inclusiveness is prioritized for marginally relevant papers, warranting acceptance for further review.

---

## [Conversation Routines: A Prompt Engineering Framework for Task-Oriented
  Dialog Systems](https://arxiv.org/abs/2501.11613v1)
**arXiv ID:** 2501.11613v1

**Abstract:**
> This study introduces Conversation Routines (CR), a structured prompt
engineering framework for developing task-oriented dialog systems using Large
Language Models (LLMs). While LLMs demonstrate remarkable natural language
understanding capabilities, engineering them to reliably execute complex
business workflows remains challenging. The proposed CR framework enables the
development of Conversation Agentic Systems (CAS) through natural language
specifications, embedding task-oriented logic within LLM prompts. This approach
provides a systematic methodology for designing and implementing complex
conversational workflows while maintaining behavioral consistency. We
demonstrate the framework's effectiveness through two proof of concept
implementations: a Train Ticket Booking System and an Interactive
Troubleshooting Copilot. These case studies validate CR's capability to encode
sophisticated behavioral patterns and decision logic while preserving natural
conversational flexibility. Results show that CR enables domain experts to
design conversational workflows in natural language while leveraging custom
enterprise functionalities (tools) developed by software engineers, creating an
efficient division of responsibilities where developers focus on core API
implementation and domain experts handle conversation design. While the
framework shows promise in accessibility and adaptability, we identify key
challenges including computational overhead, non-deterministic behavior, and
domain-specific logic optimization. Future research directions include
enhancing system robustness, improving scalability for complex multi-agent
interactions, and addressing the identified limitations across diverse business
applications.

**Decision Explanation:** Original decision: ACCEPT
Meets all required criteria: focuses on practical application of LLMs in task-oriented dialog systems (1), includes experimental results with quantitative metrics (2), and compares its methodology with existing state-of-the-art techniques (3). Additionally, it clearly describes methodology and implementation (4), discusses real-world applications and challenges (5), and shows novelty in integrating LLMs for autonomous task execution, making it a strong candidate for further review.

---

# Rejected Papers

## [The Explanation Game -- Rekindled (Extended Version)](https://arxiv.org/abs/2501.11429v1)
**arXiv ID:** 2501.11429v1

**Abstract:**
> Recent work demonstrated the existence of critical flaws in the current use
of Shapley values in explainable AI (XAI), i.e. the so-called SHAP scores.
These flaws are significant in that the scores provided to a human
decision-maker can be misleading. Although these negative results might appear
to indicate that Shapley values ought not be used in XAI, this paper argues
otherwise. Concretely, this paper proposes a novel definition of SHAP scores
that overcomes existing flaws. Furthermore, the paper outlines a practically
efficient solution for the rigorous estimation of the novel SHAP scores.
Preliminary experimental results confirm our claims, and further underscore the
flaws of the current SHAP scores.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on Explainable AI (XAI) and Shapley values, without mentioning Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, thus not meeting the required criteria related to LLMs.

---

## [Systematic Abductive Reasoning via Diverse Relation Representations in
  Vector-symbolic Architecture](https://arxiv.org/abs/2501.11896v1)
**arXiv ID:** 2501.11896v1

**Abstract:**
> In abstract visual reasoning, monolithic deep learning models suffer from
limited interpretability and generalization, while existing neuro-symbolic
approaches fall short in capturing the diversity and systematicity of
attributes and relation representations. To address these challenges, we
propose a Systematic Abductive Reasoning model with diverse relation
representations (Rel-SAR) in Vector-symbolic Architecture (VSA) to solve
Raven's Progressive Matrices (RPM). To derive attribute representations with
symbolic reasoning potential, we introduce not only various types of atomic
vectors that represent numeric, periodic and logical semantics, but also the
structured high-dimentional representation (SHDR) for the overall Grid
component. For systematic reasoning, we propose novel numerical and logical
relation functions and perform rule abduction and execution in a unified
framework that integrates these relation representations. Experimental results
demonstrate that Rel-SAR achieves significant improvement on RPM tasks and
exhibits robust out-of-distribution generalization. Rel-SAR leverages the
synergy between HD attribute representations and symbolic reasoning to achieve
systematic abductive reasoning with both interpretable and computable
semantics.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on abstract visual reasoning and solving Raven's Progressive Matrices (RPM) with Vector-symbolic Architecture (VSA), without clear connections to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, failing to meet the required criteria related to LLMs.

---

## [Bridging the Communication Gap: Evaluating AI Labeling Practices for
  Trustworthy AI Development](https://arxiv.org/abs/2501.11909v1)
**arXiv ID:** 2501.11909v1

**Abstract:**
> As artificial intelligence (AI) becomes integral to economy and society,
communication gaps between developers, users, and stakeholders hinder trust and
informed decision-making. High-level AI labels, inspired by frameworks like EU
energy labels, have been proposed to make the properties of AI models more
transparent. Without requiring deep technical expertise, they can inform on the
trade-off between predictive performance and resource efficiency. However, the
practical benefits and limitations of AI labeling remain underexplored. This
study evaluates AI labeling through qualitative interviews along four key
research questions. Based on thematic analysis and inductive coding, we found a
broad range of practitioners to be interested in AI labeling (RQ1). They see
benefits for alleviating communication gaps and aiding non-expert
decision-makers, however limitations, misunderstandings, and suggestions for
improvement were also discussed (RQ2). Compared to other reporting formats,
interviewees positively evaluated the reduced complexity of labels, increasing
overall comprehensibility (RQ3). Trust was influenced most by usability and the
credibility of the responsible labeling authority, with mixed preferences for
self-certification versus third-party certification (RQ4). Our Insights
highlight that AI labels pose a trade-off between simplicity and complexity,
which could be resolved by developing customizable and interactive labeling
frameworks to address diverse user needs. Transparent labeling of resource
efficiency also nudged interviewee priorities towards paying more attention to
sustainability aspects during AI development. This study validates AI labels as
a valuable tool for enhancing trust and communication in AI, offering
actionable guidelines for their refinement and standardization.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on trustworthy AI development, AI ethics (transparent labeling, trust, and responsible AI development), which falls under the rejection criteria (responsible AI application or AI ethics). It also lacks clear connections to Large Language Models (LLMs), practical applications in knowledge graphs, retrieval-augmented generation, or agentic AI as required by the selection criteria.

---

## [Make Full Use of Testing Information: An Integrated Accelerated Testing
  and Evaluation Method for Autonomous Driving Systems](https://arxiv.org/abs/2501.11924v1)
**arXiv ID:** 2501.11924v1

**Abstract:**
> Testing and evaluation is an important step before the large-scale
application of the autonomous driving systems (ADSs). Based on the three level
of scenario abstraction theory, a testing can be performed within a logical
scenario, followed by an evaluation stage which is inputted with the testing
results of each concrete scenario generated from the logical parameter space.
During the above process, abundant testing information is produced which is
beneficial for comprehensive and accurate evaluations. To make full use of
testing information, this paper proposes an Integrated accelerated Testing and
Evaluation Method (ITEM). Based on a Monte Carlo Tree Search (MCTS) paradigm
and a dual surrogates testing framework proposed in our previous work, this
paper applies the intermediate information (i.e., the tree structure, including
the affiliation of each historical sampled point with the subspaces and the
parent-child relationship between subspaces) generated during the testing stage
into the evaluation stage to achieve accurate hazardous domain identification.
Moreover, to better serve this purpose, the UCB calculation method is improved
to allow the search algorithm to focus more on the hazardous domain boundaries.
Further, a stopping condition is constructed based on the convergence of the
search algorithm. Ablation and comparative experiments are then conducted to
verify the effectiveness of the improvements and the superiority of the
proposed method. The experimental results show that ITEM could well identify
the hazardous domains in both low- and high-dimensional cases, regardless of
the shape of the hazardous domains, indicating its generality and potential for
the safety evaluation of ADSs.

**Decision Explanation:** Original response: ```
{
    "decision": "REJECT",
    "explanation": "The paper primarily focuses on autonomous driving systems (ADSs) without explicitly involving Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, thus failing to meet the mandatory criteria related to LLMs."
}
```

---

## [Collaborative Imputation of Urban Time Series through Cross-city
  Meta-learning](https://arxiv.org/abs/2501.11306v1)
**arXiv ID:** 2501.11306v1

**Abstract:**
> Urban time series, such as mobility flows, energy consumption, and pollution
records, encapsulate complex urban dynamics and structures. However, data
collection in each city is impeded by technical challenges such as budget
limitations and sensor failures, necessitating effective data imputation
techniques that can enhance data quality and reliability. Existing imputation
models, categorized into learning-based and analytics-based paradigms, grapple
with the trade-off between capacity and generalizability. Collaborative
learning to reconstruct data across multiple cities holds the promise of
breaking this trade-off. Nevertheless, urban data's inherent irregularity and
heterogeneity issues exacerbate challenges of knowledge sharing and
collaboration across cities. To address these limitations, we propose a novel
collaborative imputation paradigm leveraging meta-learned implicit neural
representations (INRs). INRs offer a continuous mapping from domain coordinates
to target values, integrating the strengths of both paradigms. By imposing
embedding theory, we first employ continuous parameterization to handle
irregularity and reconstruct the dynamical system. We then introduce a
cross-city collaborative learning scheme through model-agnostic meta learning,
incorporating hierarchical modulation and normalization techniques to
accommodate multiscale representations and reduce variance in response to
heterogeneity. Extensive experiments on a diverse urban dataset from 20 global
cities demonstrate our model's superior imputation performance and
generalizability, underscoring the effectiveness of collaborative imputation in
resource-constrained settings.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on urban time series imputation using meta-learning, without any apparent connection to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, thus failing to meet the mandatory criteria (1, 2, and 3) related to LLMs.

---

## [Finer-CAM: Spotting the Difference Reveals Finer Details for Visual
  Explanation](https://arxiv.org/abs/2501.11309v1)
**arXiv ID:** 2501.11309v1

**Abstract:**
> Class activation map (CAM) has been widely used to highlight image regions
that contribute to class predictions. Despite its simplicity and computational
efficiency, CAM often struggles to identify discriminative regions that
distinguish visually similar fine-grained classes. Prior efforts address this
limitation by introducing more sophisticated explanation processes, but at the
cost of extra complexity. In this paper, we propose Finer-CAM, a method that
retains CAM's efficiency while achieving precise localization of discriminative
regions. Our key insight is that the deficiency of CAM lies not in "how" it
explains, but in "what" it explains}. Specifically, previous methods attempt to
identify all cues contributing to the target class's logit value, which
inadvertently also activates regions predictive of visually similar classes. By
explicitly comparing the target class with similar classes and spotting their
differences, Finer-CAM suppresses features shared with other classes and
emphasizes the unique, discriminative details of the target class. Finer-CAM is
easy to implement, compatible with various CAM methods, and can be extended to
multi-modal models for accurate localization of specific concepts.
Additionally, Finer-CAM allows adjustable comparison strength, enabling users
to selectively highlight coarse object contours or fine discriminative details.
Quantitatively, we show that masking out the top 5% of activated pixels by
Finer-CAM results in a larger relative confidence drop compared to baselines.
The source code and demo are available at
https://github.com/Imageomics/Finer-CAM.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on image processing and visual explanation using Class Activation Maps (CAM), with no apparent connection to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, failing to meet the fundamental criteria.

---

## [CatV2TON: Taming Diffusion Transformers for Vision-Based Virtual Try-On
  with Temporal Concatenation](https://arxiv.org/abs/2501.11325v1)
**arXiv ID:** 2501.11325v1

**Abstract:**
> Virtual try-on (VTON) technology has gained attention due to its potential to
transform online retail by enabling realistic clothing visualization of images
and videos. However, most existing methods struggle to achieve high-quality
results across image and video try-on tasks, especially in long video
scenarios. In this work, we introduce CatV2TON, a simple and effective
vision-based virtual try-on (V2TON) method that supports both image and video
try-on tasks with a single diffusion transformer model. By temporally
concatenating garment and person inputs and training on a mix of image and
video datasets, CatV2TON achieves robust try-on performance across static and
dynamic settings. For efficient long-video generation, we propose an
overlapping clip-based inference strategy that uses sequential frame guidance
and Adaptive Clip Normalization (AdaCN) to maintain temporal consistency with
reduced resource demands. We also present ViViD-S, a refined video try-on
dataset, achieved by filtering back-facing frames and applying 3D mask
smoothing for enhanced temporal consistency. Comprehensive experiments
demonstrate that CatV2TON outperforms existing methods in both image and video
try-on tasks, offering a versatile and reliable solution for realistic virtual
try-ons across diverse scenarios.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on computer vision for virtual try-on, particularly in video processing, which is explicitly listed as a rejection criterion. Additionally, it lacks apparent connection to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, which are key areas of interest.

---

## [Federated Learning with Sample-level Client Drift Mitigation](https://arxiv.org/abs/2501.11360v1)
**arXiv ID:** 2501.11360v1

**Abstract:**
> Federated Learning (FL) suffers from severe performance degradation due to
the data heterogeneity among clients. Existing works reveal that the
fundamental reason is that data heterogeneity can cause client drift where the
local model update deviates from the global one, and thus they usually tackle
this problem from the perspective of calibrating the obtained local update.
Despite effectiveness, existing methods substantially lack a deep understanding
of how heterogeneous data samples contribute to the formation of client drift.
In this paper, we bridge this gap by identifying that the drift can be viewed
as a cumulative manifestation of biases present in all local samples and the
bias between samples is different. Besides, the bias dynamically changes as the
FL training progresses. Motivated by this, we propose FedBSS that first
mitigates the heterogeneity issue in a sample-level manner, orthogonal to
existing methods. Specifically, the core idea of our method is to adopt a
bias-aware sample selection scheme that dynamically selects the samples from
small biases to large epoch by epoch to train progressively the local model in
each round. In order to ensure the stability of training, we set the
diversified knowledge acquisition stage as the warm-up stage to avoid the local
optimality caused by knowledge deviation in the early stage of the model.
Evaluation results show that FedBSS outperforms state-of-the-art baselines. In
addition, we also achieved effective results on feature distribution skew and
noise label dataset setting, which proves that FedBSS can not only reduce
heterogeneity, but also has scalability and robustness.

**Decision Explanation:** Original decision: REJECT
The paper focuses on Federated Learning, which, while related to AI, does not explicitly mention Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, thus not meeting the primary criteria. Additionally, the topic aligns more closely with general AI challenges rather than the specified areas of interest.

---

## [Multi-View Spectral Clustering for Graphs with Multiple View Structures](https://arxiv.org/abs/2501.11422v1)
**arXiv ID:** 2501.11422v1

**Abstract:**
> Despite the fundamental importance of clustering, to this day, much of the
relevant research is still based on ambiguous foundations, leading to an
unclear understanding of whether or how the various clustering methods are
connected with each other. In this work, we provide an additional stepping
stone towards resolving such ambiguities by presenting a general clustering
framework that subsumes a series of seemingly disparate clustering methods,
including various methods belonging to the wildly popular spectral clustering
framework. In fact, the generality of the proposed framework is additionally
capable of shedding light to the largely unexplored area of multi-view graphs
whose each view may have differently clustered nodes. In turn, we propose
GenClus: a method that is simultaneously an instance of this framework and a
generalization of spectral clustering, while also being closely related to
k-means as well. This results in a principled alternative to the few existing
methods studying this special type of multi-view graphs. Then, we conduct
in-depth experiments, which demonstrate that GenClus is more computationally
efficient than existing methods, while also attaining similar or better
clustering performance. Lastly, a qualitative real-world case-study further
demonstrates the ability of GenClus to produce meaningful clusterings.

**Decision Explanation:** Original decision: REJECT
The paper does not mention Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, failing to meet the primary criteria (1) for practical applications of LLMs, and lacking clear connections to the specified areas of interest.

---

## [A Survey on Diffusion Models for Anomaly Detection](https://arxiv.org/abs/2501.11430v1)
**arXiv ID:** 2501.11430v1

**Abstract:**
> Diffusion models (DMs) have emerged as a powerful class of generative AI
models, showing remarkable potential in anomaly detection (AD) tasks across
various domains, such as cybersecurity, fraud detection, healthcare, and
manufacturing. The intersection of these two fields, termed diffusion models
for anomaly detection (DMAD), offers promising solutions for identifying
deviations in increasingly complex and high-dimensional data. In this survey,
we systematically review recent advances in DMAD research and investigate their
capabilities. We begin by presenting the fundamental concepts of AD and DMs,
followed by a comprehensive analysis of classic DM architectures including
DDPMs, DDIMs, and Score SDEs. We further categorize existing DMAD methods into
reconstruction-based, density-based, and hybrid approaches, providing detailed
examinations of their methodological innovations. We also explore the diverse
tasks across different data modalities, encompassing image, time series, video,
and multimodal data analysis. Furthermore, we discuss critical challenges and
emerging research directions, including computational efficiency, model
interpretability, robustness enhancement, edge-cloud collaboration, and
integration with large language models. The collection of DMAD research papers
and resources is available at https://github.com/fdjingliu/DMAD.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on diffusion models for anomaly detection in various domains (including healthcare and video processing), with no clear indication of practical applications or experimental results specifically involving Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, thus failing to meet the required criteria.

---

## [Communication-Efficient Federated Learning Based on Explanation-Guided
  Pruning for Remote Sensing Image Classification](https://arxiv.org/abs/2501.11493v1)
**arXiv ID:** 2501.11493v1

**Abstract:**
> Federated learning (FL) is a decentralized machine learning paradigm, where
multiple clients collaboratively train a global model by exchanging only model
updates with the central server without sharing the local data of clients. Due
to the large volume of model updates required to be transmitted between clients
and the central server, most FL systems are associated with high transfer costs
(i.e., communication overhead). This issue is more critical for operational
applications in remote sensing (RS), especially when large-scale RS data is
processed and analyzed through FL systems with restricted communication
bandwidth. To address this issue, we introduce an explanation-guided pruning
strategy for communication-efficient FL in the context of RS image
classification. Our pruning strategy is defined based on the layerwise
relevance propagation (LRP) driven explanations to: 1) efficiently and
effectively identify the most relevant and informative model parameters (to be
exchanged between clients and the central server); and 2) eliminate the
non-informative ones to minimize the volume of model updates. The experimental
results on the BigEarthNet-S2 dataset demonstrate that our strategy effectively
reduces the number of shared model updates, while increasing the generalization
ability of the global model. The code of this work will be publicly available
at https://git.tu-berlin.de/rsim/FL-LRP

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on Federated Learning for Remote Sensing Image Classification, with no apparent connection to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, thus failing to meet the core criteria.

---

## [Meta-Instance Selection. Instance Selection as a Classification Problem
  with Meta-Features](https://arxiv.org/abs/2501.11526v1)
**arXiv ID:** 2501.11526v1

**Abstract:**
> Data pruning, or instance selection, is an important problem in machine
learning especially in terms of nearest neighbour classifier. However, in data
pruning which speeds up the prediction phase, there is an issue related to the
speed and efficiency of the process itself. In response, the study proposes an
approach involving transforming the instance selection process into a
classification task conducted in a unified meta-feature space where each
instance can be classified and assigned to either the "to keep" or "to remove"
class. This approach requires training an appropriate meta-classifier, which
can be developed based on historical instance selection results from other
datasets using reference instance selection methods as a labeling tool. This
work proposes constructing the meta-feature space based on properties extracted
from the nearest neighbor graph. Experiments conducted on 17 datasets of
varying sizes and five reference instance selection methods (ENN, Drop3, ICF,
HMN-EI, and CCIS) demonstrate that the proposed solution achieves results
comparable to reference instance selection methods while significantly reducing
computational complexity. In the proposed approach, the computational
complexity of the system depends only on identifying the k-nearest neighbors
for each data sample and running the meta-classifier. Additionally, the study
discusses the choice of meta-classifier, recommending the use of Balanced
Random Forest.

**Decision Explanation:** Original decision: REJECT
The paper does not meet the primary criteria for Large Language Models (LLMs) applications, focusing instead on instance selection and classification in machine learning with nearest neighbor classifiers, without any mention of LLMs, knowledge graphs, retrieval-augmented generation, or agentic AI.

---

## [The impact of intrinsic rewards on exploration in Reinforcement Learning](https://arxiv.org/abs/2501.11533v1)
**arXiv ID:** 2501.11533v1

**Abstract:**
> One of the open challenges in Reinforcement Learning is the hard exploration
problem in sparse reward environments. Various types of intrinsic rewards have
been proposed to address this challenge by pushing towards diversity. This
diversity might be imposed at different levels, favouring the agent to explore
different states, policies or behaviours (State, Policy and Skill level
diversity, respectively). However, the impact of diversity on the agent's
behaviour remains unclear. In this work, we aim to fill this gap by studying
the effect of different levels of diversity imposed by intrinsic rewards on the
exploration patterns of RL agents. We select four intrinsic rewards (State
Count, Intrinsic Curiosity Module (ICM), Maximum Entropy, and Diversity is all
you need (DIAYN)), each pushing for a different diversity level. We conduct an
empirical study on MiniGrid environment to compare their impact on exploration
considering various metrics related to the agent's exploration, namely:
episodic return, observation coverage, agent's position coverage, policy
entropy, and timeframes to reach the sparse reward. The main outcome of the
study is that State Count leads to the best exploration performance in the case
of low-dimensional observations. However, in the case of RGB observations, the
performance of State Count is highly degraded mostly due to representation
learning challenges. Conversely, Maximum Entropy is less impacted, resulting in
a more robust exploration, despite being not always optimal. Lastly, our
empirical study revealed that learning diverse skills with DIAYN, often linked
to improved robustness and generalisation, does not promote exploration in
MiniGrid environments. This is because: i) learning the skill space itself can
be challenging, and ii) exploration within the skill space prioritises
differentiating between behaviours rather than achieving uniform state
visitation.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on Reinforcement Learning (RL) with intrinsic rewards, without mentioning Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, thus failing to meet the required criteria related to LLMs.

---

## [Spatially-Delineated Domain-Adapted AI Classification: An Application
  for Oncology Data](https://arxiv.org/abs/2501.11695v1)
**arXiv ID:** 2501.11695v1

**Abstract:**
> Given multi-type point maps from different place-types (e.g., tumor regions),
our objective is to develop a classifier trained on the source place-type to
accurately distinguish between two classes of the target place-type based on
their point arrangements. This problem is societally important for many
applications, such as generating clinical hypotheses for designing new
immunotherapies for cancer treatment. The challenge lies in the spatial
variability, the inherent heterogeneity and variation observed in spatial
properties or arrangements across different locations (i.e., place-types).
Previous techniques focus on self-supervised tasks to learn domain-invariant
features and mitigate domain differences; however, they often neglect the
underlying spatial arrangements among data points, leading to significant
discrepancies across different place-types. We explore a novel multi-task
self-learning framework that targets spatial arrangements, such as spatial
mix-up masking and spatial contrastive predictive coding, for
spatially-delineated domain-adapted AI classification. Experimental results on
real-world datasets (e.g., oncology data) show that the proposed framework
provides higher prediction accuracy than baseline methods.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on medical applications of AI (oncology data for cancer treatment), which is one of the explicit rejection criteria.

---

## [Human services organizations and the responsible integration of AI:
  Considering ethics and contextualizing risk(s)](https://arxiv.org/abs/2501.11705v1)
**arXiv ID:** 2501.11705v1

**Abstract:**
> This paper examines the responsible integration of artificial intelligence
(AI) in human services organizations (HSOs), proposing a nuanced framework for
evaluating AI applications across multiple dimensions of risk. The authors
argue that ethical concerns about AI deployment -- including professional
judgment displacement, environmental impact, model bias, and data laborer
exploitation -- vary significantly based on implementation context and specific
use cases. They challenge the binary view of AI adoption, demonstrating how
different applications present varying levels of risk that can often be
effectively managed through careful implementation strategies. The paper
highlights promising solutions, such as local large language models, that can
facilitate responsible AI integration while addressing common ethical concerns.
The authors propose a dimensional risk assessment approach that considers
factors like data sensitivity, professional oversight requirements, and
potential impact on client wellbeing. They conclude by outlining a path forward
that emphasizes empirical evaluation, starting with lower-risk applications and
building evidence-based understanding through careful experimentation. This
approach enables organizations to maintain high ethical standards while
thoughtfully exploring how AI might enhance their capacity to serve clients and
communities effectively.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on responsible AI application or AI ethics, which is explicitly listed as a criterion for rejection, overshadowing any potential marginal relevance to Large Language Models (LLMs) or other specified areas of interest.

---

## [GL-ICNN: An End-To-End Interpretable Convolutional Neural Network for
  the Diagnosis and Prediction of Alzheimer's Disease](https://arxiv.org/abs/2501.11715v1)
**arXiv ID:** 2501.11715v1

**Abstract:**
> Deep learning methods based on Convolutional Neural Networks (CNNs) have
shown great potential to improve early and accurate diagnosis of Alzheimer's
disease (AD) dementia based on imaging data. However, these methods have yet to
be widely adopted in clinical practice, possibly due to the limited
interpretability of deep learning models. The Explainable Boosting Machine
(EBM) is a glass-box model but cannot learn features directly from input
imaging data. In this study, we propose a novel interpretable model that
combines CNNs and EBMs for the diagnosis and prediction of AD. We develop an
innovative training strategy that alternatingly trains the CNN component as a
feature extractor and the EBM component as the output block to form an
end-to-end model. The model takes imaging data as input and provides both
predictions and interpretable feature importance measures. We validated the
proposed model on the Alzheimer's Disease Neuroimaging Initiative (ADNI)
dataset and the Health-RI Parelsnoer Neurodegenerative Diseases Biobank (PND)
as an external testing set. The proposed model achieved an area-under-the-curve
(AUC) of 0.956 for AD and control classification, and 0.694 for the prediction
of conversion of mild cognitive impairment (MCI) to AD on the ADNI cohort. The
proposed model is a glass-box model that achieves a comparable performance with
other state-of-the-art black-box models. Our code is publicly available at:
https://anonymous.4open.science/r/GL-ICNN.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on medical applications of AI (Alzheimer's Disease diagnosis and prediction), which is explicitly listed as a rejection criterion.

---

## [Episodic memory in AI agents poses risks that should be studied and
  mitigated](https://arxiv.org/abs/2501.11739v1)
**arXiv ID:** 2501.11739v1

**Abstract:**
> Most current AI models have little ability to store and later retrieve a
record or representation of what they do. In human cognition, episodic memories
play an important role in both recall of the past as well as planning for the
future. The ability to form and use episodic memories would similarly enable a
broad range of improved capabilities in an AI agent that interacts with and
takes actions in the world. Researchers have begun directing more attention to
developing memory abilities in AI models. It is therefore likely that models
with such capability will be become widespread in the near future. This could
in some ways contribute to making such AI agents safer by enabling users to
better monitor, understand, and control their actions. However, as a new
capability with wide applications, we argue that it will also introduce
significant new risks that researchers should begin to study and address. We
outline these risks and benefits and propose four principles to guide the
development of episodic memory capabilities so that these will enhance, rather
than undermine, the effort to keep AI safe and trustworthy.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on responsible AI application and AI safety/ethics, which is an explicitly stated rejection criterion, and does not appear to meet the required criteria related to practical applications, experimental results, or state-of-the-art comparisons for Large Language Models (LLMs).

---

## [PXGen: A Post-hoc Explainable Method for Generative Models](https://arxiv.org/abs/2501.11827v1)
**arXiv ID:** 2501.11827v1

**Abstract:**
> With the rapid growth of generative AI in numerous applications, explainable
AI (XAI) plays a crucial role in ensuring the responsible development and
deployment of generative AI technologies. XAI has undergone notable
advancements and widespread adoption in recent years, reflecting a concerted
push to enhance the transparency, interpretability, and credibility of AI
systems. Recent research emphasizes that a proficient XAI method should adhere
to a set of criteria, primarily focusing on two key areas. Firstly, it should
ensure the quality and fluidity of explanations, encompassing aspects like
faithfulness, plausibility, completeness, and tailoring to individual needs.
Secondly, the design principle of the XAI system or mechanism should cover the
following factors such as reliability, resilience, the verifiability of its
outputs, and the transparency of its algorithm. However, research in XAI for
generative models remains relatively scarce, with little exploration into how
such methods can effectively meet these criteria in that domain. In this work,
we propose PXGen, a post-hoc explainable method for generative models. Given a
model that needs to be explained, PXGen prepares two materials for the
explanation, the Anchor set and intrinsic & extrinsic criteria. Those materials
are customizable by users according to their purpose and requirements. Via the
calculation of each criterion, each anchor has a set of feature values and
PXGen provides examplebased explanation methods according to the feature values
among all the anchors and illustrated and visualized to the users via tractable
algorithms such as k-dispersion or k-center.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on Explainable AI (XAI) and responsible development of AI technologies, which aligns with 'responsible AI application or AI ethics', a criterion for rejection. Additionally, it lacks clear connections to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI as required by the selection criteria.

---

## [A Survey on Memory-Efficient Large-Scale Model Training in AI for
  Science](https://arxiv.org/abs/2501.11847v1)
**arXiv ID:** 2501.11847v1

**Abstract:**
> Scientific research faces high costs and inefficiencies with traditional
methods, but the rise of deep learning and large language models (LLMs) offers
innovative solutions. This survey reviews LLM applications across scientific
fields such as biology, medicine, chemistry, and meteorology, underscoring
their role in advancing research. However, the continuous expansion of model
size has led to significant memory demands, hindering further development and
application of LLMs for science. To address this, we review memory-efficient
training techniques for LLMs based on the transformer architecture, including
distributed training, mixed precision training, and gradient checkpointing.
Using AlphaFold 2 as an example, we demonstrate how tailored memory
optimization methods can reduce storage needs while preserving prediction
accuracy. We also discuss the challenges of memory optimization in practice and
potential future directions, hoping to provide valuable insights for
researchers and engineers.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on scientific applications, with a notable emphasis on biology and medicine, which aligns with excluded topics (primarily medical applications of AI). While it touches on Large Language Models, the core application area (science, including medicine) does not meet the inclusion criteria.

---

## [Coarse-to-Fine Lightweight Meta-Embedding for ID-Based Recommendation](https://arxiv.org/abs/2501.11870v1)
**arXiv ID:** 2501.11870v1

**Abstract:**
> The state-of-the-art recommendation systems have shifted the attention to
efficient recommendation, e.g., on-device recommendation, under memory
constraints. To this end, the existing methods either focused on the
lightweight embeddings for both users and items, or involved on-device systems
enjoying the compact embeddings to enhance reusability and reduces space
complexity. However, they focus solely on the coarse granularity of embedding,
while overlook the fine-grained semantic nuances, to adversarially downgrade
the efficacy of meta-embeddings in capturing the intricate relationship over
both user and item, consequently resulting into the suboptimal recommendations.
In this paper, we aim to study how the meta-embedding can efficiently learn
varied grained semantics, together with how the fine-grained meta-embedding can
strengthen the representation of coarse-grained meta-embedding. To answer these
questions, we develop a novel graph neural networks (GNNs) based recommender
where each user and item serves as the node, linked directly to coarse-grained
virtual nodes and indirectly to fine-grained virtual nodes, ensuring different
grained semantic learning, while disclosing: 1) In contrast to coarse-grained
semantics, fine-grained semantics are well captured through sparse
meta-embeddings, which adaptively 2) balance the embedding uniqueness and
memory constraint. Additionally, the initialization method come up upon
SparsePCA, along with a soft thresholding activation function to render the
sparseness of the meta-embeddings. We propose a weight bridging update strategy
that focuses on matching each coarse-grained meta-embedding with several
fine-grained meta-embeddings based on the users/items' semantics. Extensive
experiments substantiate our method's superiority over existing baselines. Our
code is available at https://github.com/htyjers/C2F-MetaEmbed.

**Decision Explanation:** Original response: ```
{
    "decision": "REJECT",
    "explanation": "The paper does not meet the primary criteria related to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI. It focuses on recommendation systems using graph neural networks (GNNs) and meta-embeddings, which falls outside the specified areas of interest."
}
```

---

## [Community-Aware Temporal Walks: Parameter-Free Representation Learning
  on Continuous-Time Dynamic Graphs](https://arxiv.org/abs/2501.11880v1)
**arXiv ID:** 2501.11880v1

**Abstract:**
> Dynamic graph representation learning plays a crucial role in understanding
evolving behaviors. However, existing methods often struggle with flexibility,
adaptability, and the preservation of temporal and structural dynamics. To
address these issues, we propose Community-aware Temporal Walks (CTWalks), a
novel framework for representation learning on continuous-time dynamic graphs.
CTWalks integrates three key components: a community-based parameter-free
temporal walk sampling mechanism, an anonymization strategy enriched with
community labels, and an encoding process that leverages continuous temporal
dynamics modeled via ordinary differential equations (ODEs). This design
enables precise modeling of both intra- and inter-community interactions,
offering a fine-grained representation of evolving temporal patterns in
continuous-time dynamic graphs. CTWalks theoretically overcomes locality bias
in walks and establishes its connection to matrix factorization. Experiments on
benchmark datasets demonstrate that CTWalks outperforms established methods in
temporal link prediction tasks, achieving higher accuracy while maintaining
robustness.

**Decision Explanation:** Original decision: REJECT
The paper does not meet any of the primary criteria for Large Language Models (LLMs) applications, focusing instead on dynamic graph representation learning, temporal walk sampling, and ordinary differential equations (ODEs), with no apparent connection to LLMs, knowledge graphs, retrieval-augmented generation, or agentic AI.

---

## [LuxVeri at GenAI Detection Task 1: Inverse Perplexity Weighted Ensemble
  for Robust Detection of AI-Generated Text across English and Multilingual
  Contexts](https://arxiv.org/abs/2501.11914v1)
**arXiv ID:** 2501.11914v1

**Abstract:**
> This paper presents a system developed for Task 1 of the COLING 2025 Workshop
on Detecting AI-Generated Content, focusing on the binary classification of
machine-generated versus human-written text. Our approach utilizes an ensemble
of models, with weights assigned according to each model's inverse perplexity,
to enhance classification accuracy. For the English text detection task, we
combined RoBERTa-base, RoBERTa-base with the OpenAI detector, and
BERT-base-cased, achieving a Macro F1-score of 0.7458, which ranked us 12th out
of 35 teams. We ensembled RemBERT, XLM-RoBERTa-base, and
BERT-base-multilingual-case for the multilingual text detection task, employing
the same inverse perplexity weighting technique. This resulted in a Macro
F1-score of 0.7513, positioning us 4th out of 25 teams. Our results demonstrate
the effectiveness of inverse perplexity weighting in improving the robustness
of machine-generated text detection across both monolingual and multilingual
settings, highlighting the potential of ensemble methods for this challenging
task.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on detecting AI-generated text, which does not explicitly align with the specified practical applications of Large Language Models (LLMs) in areas like knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, and does not clearly meet the criteria for real-world applications, methodology, or novelty in the context of LLMs as outlined.

---

## [LuxVeri at GenAI Detection Task 3: Cross-Domain Detection of
  AI-Generated Text Using Inverse Perplexity-Weighted Ensemble of Fine-Tuned
  Transformer Models](https://arxiv.org/abs/2501.11918v1)
**arXiv ID:** 2501.11918v1

**Abstract:**
> This paper presents our approach for Task 3 of the GenAI content detection
workshop at COLING-2025, focusing on Cross-Domain Machine-Generated Text (MGT)
Detection. We propose an ensemble of fine-tuned transformer models, enhanced by
inverse perplexity weighting, to improve classification accuracy across diverse
text domains. For Subtask A (Non-Adversarial MGT Detection), we combined a
fine-tuned RoBERTa-base model with an OpenAI detector-integrated RoBERTa-base
model, achieving an aggregate TPR score of 0.826, ranking 10th out of 23
detectors. In Subtask B (Adversarial MGT Detection), our fine-tuned
RoBERTa-base model achieved a TPR score of 0.801, securing 8th out of 22
detectors. Our results demonstrate the effectiveness of inverse
perplexity-based weighting for enhancing generalization and performance in both
non-adversarial and adversarial MGT detection, highlighting the potential for
transformer models in cross-domain AI-generated content detection.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on AI-generated text detection, which does not explicitly align with the practical applications of Large Language Models (LLMs) in areas like knowledge graphs, retrieval-augmented generation (RAG), or agentic AI. While it meets some criteria (e.g., experimental results, comparison with state-of-the-art), its core application does not satisfy the mandatory criteria for practical applications of LLMs as specified.

---

## [A Lightweight and Interpretable Deepfakes Detection Framework](https://arxiv.org/abs/2501.11927v1)
**arXiv ID:** 2501.11927v1

**Abstract:**
> The recent realistic creation and dissemination of so-called deepfakes poses
a serious threat to social life, civil rest, and law. Celebrity defaming,
election manipulation, and deepfakes as evidence in court of law are few
potential consequences of deepfakes. The availability of open source trained
models based on modern frameworks such as PyTorch or TensorFlow, video
manipulations Apps such as FaceApp and REFACE, and economical computing
infrastructure has easen the creation of deepfakes. Most of the existing
detectors focus on detecting either face-swap, lip-sync, or puppet master
deepfakes, but a unified framework to detect all three types of deepfakes is
hardly explored. This paper presents a unified framework that exploits the
power of proposed feature fusion of hybrid facial landmarks and our novel heart
rate features for detection of all types of deepfakes. We propose novel heart
rate features and fused them with the facial landmark features to better
extract the facial artifacts of fake videos and natural variations available in
the original videos. We used these features to train a light-weight XGBoost to
classify between the deepfake and bonafide videos. We evaluated the performance
of our framework on the world leaders dataset (WLDR) that contains all types of
deepfakes. Experimental results illustrate that the proposed framework offers
superior detection performance over the comparative deepfakes detection
methods. Performance comparison of our framework against the LSTM-FCN, a
candidate of deep learning model, shows that proposed model achieves similar
results, however, it is more interpretable.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on video processing (deepfakes detection), which is one of the criteria for rejection. Additionally, it touches on social implications (e.g., social life, civil unrest, law), another area for rejection. The paper does not appear to involve Large Language Models (LLMs) or related key areas like knowledge graphs, retrieval-augmented generation (RAG), or agentic AI.

---

## [Webvs. LLMs: An Empirical Study of Learning Behaviors of CS2 Students](https://arxiv.org/abs/2501.11935v1)
**arXiv ID:** 2501.11935v1

**Abstract:**
> LLMs such as ChatGPT have been widely adopted by students in higher education
as tools for learning programming and related concepts. However, it remains
unclear how effective students are and what strategies students use while
learning with LLMs. Since the majority of students' experiences in online
self-learning have come through using search engines such as Google, evaluating
AI tools in this context can help us address these gaps. In this mixed methods
research, we conducted an exploratory within-subjects study to understand how
CS2 students learn programming concepts using both LLMs as well as traditional
online methods such as educational websites and videos to examine how students
approach learning within and across both scenarios. We discovered that students
found it easier to learn a more difficult concept using traditional methods
than using ChatGPT. We also found that students ask fewer follow-ups and use
more keyword-based queries for search engines while their prompts to LLMs tend
to explicitly ask for information.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on educational applications of LLMs, which, while not explicitly listed for rejection, does not align with the preferred areas (knowledge graphs, RAG, agentic AI). It also lacks clear connections to practical real-world applications beyond educational settings, and its main findings relate to learning behaviors rather than showcasing innovative LLM applications, improvements, or state-of-the-art comparisons.

---

## [MeshONet: A Generalizable and Efficient Operator Learning Method for
  Structured Mesh Generation](https://arxiv.org/abs/2501.11937v1)
**arXiv ID:** 2501.11937v1

**Abstract:**
> Mesh generation plays a crucial role in scientific computing. Traditional
mesh generation methods, such as TFI and PDE-based methods, often struggle to
achieve a balance between efficiency and mesh quality. To address this
challenge, physics-informed intelligent learning methods have recently emerged,
significantly improving generation efficiency while maintaining high mesh
quality. However, physics-informed methods fail to generalize when applied to
previously unseen geometries, as even small changes in the boundary shape
necessitate burdensome retraining to adapt to new geometric variations. In this
paper, we introduce MeshONet, the first generalizable intelligent learning
method for structured mesh generation. The method transforms the mesh
generation task into an operator learning problem with multiple input and
solution functions. To effectively overcome the multivariable mapping
restriction of operator learning methods, we propose a dual-branch,
shared-trunk architecture to approximate the mapping between function spaces
based on input-output pairs. Experimental results show that MeshONet achieves a
speedup of up to four orders of magnitude in generation efficiency over
traditional methods. It also enables generalization to different geometries
without retraining, greatly enhancing the practicality of intelligent methods.

**Decision Explanation:** Original decision: REJECT
The paper does not meet any of the required criteria, focusing on mesh generation for scientific computing, which is unrelated to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, and does not address real-world applications or challenges specific to LLMs.

---

## [Survey on Hand Gesture Recognition from Visual Input](https://arxiv.org/abs/2501.11992v1)
**arXiv ID:** 2501.11992v1

**Abstract:**
> Hand gesture recognition has become an important research area, driven by the
growing demand for human-computer interaction in fields such as sign language
recognition, virtual and augmented reality, and robotics. Despite the rapid
growth of the field, there are few surveys that comprehensively cover recent
research developments, available solutions, and benchmark datasets. This survey
addresses this gap by examining the latest advancements in hand gesture and 3D
hand pose recognition from various types of camera input data including RGB
images, depth images, and videos from monocular or multiview cameras, examining
the differing methodological requirements of each approach. Furthermore, an
overview of widely used datasets is provided, detailing their main
characteristics and application domains. Finally, open challenges such as
achieving robust recognition in real-world environments, handling occlusions,
ensuring generalization across diverse users, and addressing computational
efficiency for real-time applications are highlighted to guide future research
directions. By synthesizing the objectives, methodologies, and applications of
recent studies, this survey offers valuable insights into current trends,
challenges, and opportunities for future research in human hand gesture
recognition.

**Decision Explanation:** Original decision: REJECT
The paper does not meet any of the required criteria, as it focuses on hand gesture recognition from visual input, which is unrelated to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, and also falls under the rejection category of primarily focusing on video processing.

---

## [Full Proportional Justified Representation](https://arxiv.org/abs/2501.12015v1)
**arXiv ID:** 2501.12015v1

**Abstract:**
> In multiwinner approval voting, forming a committee that proportionally
represents voters' approval ballots is an essential task. The notion of
justified representation (JR) demands that any large "cohesive" group of voters
should be proportionally "represented". The "cohesiveness" is defined in
different ways; two common ways are the following: (C1) demands that the group
unanimously approves a set of candidates proportional to its size, while (C2)
requires each member to approve at least a fixed fraction of such a set.
Similarly, "representation" have been considered in different ways: (R1) the
coalition's collective utility from the winning set exceeds that of any
proportionally sized alternative, and (R2) for any proportionally sized
alternative, at least one member of the coalition derives less utility from it
than from the winning set.
  Three of the four possible combinations have been extensively studied:
(C1)-(R1) defines Proportional Justified Representation (PJR), (C1)-(R2)
defines Extended Justified Representation (EJR), (C2)-(R2) defines Full
Justified Representation (FJR). All three have merits, but also drawbacks. PJR
is the weakest notion, and perhaps not sufficiently demanding; EJR may not be
compatible with perfect representation; and it is open whether a committee
satisfying FJR can be found efficiently.
  We study the combination (C2)-(R1), which we call Full Proportional Justified
Representation (FPJR). We investigate FPJR's properties and find that it shares
PJR's advantages over EJR: several proportionality axioms (e.g. priceability,
perfect representation) imply FPJR and PJR but not EJR. We also find that
efficient rules like the greedy Monroe rule and the method of equal shares
satisfy FPJR, matching a key advantage of EJR over FJR. However, the
Proportional Approval Voting (PAV) rule may violate FPJR, so neither of EJR and
FPJR implies the other.

**Decision Explanation:** Original decision: REJECT
The paper does not meet any of the required criteria, focusing on voting systems and proportional representation rather than Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation, or agentic AI, and lacks relevance to the specified areas of interest.

---

## [Adaptive Class Learning to Screen Diabetic Disorders in Fundus Images of
  Eye](https://arxiv.org/abs/2501.12048v1)
**arXiv ID:** 2501.12048v1

**Abstract:**
> The prevalence of ocular illnesses is growing globally, presenting a
substantial public health challenge. Early detection and timely intervention
are crucial for averting visual impairment and enhancing patient prognosis.
This research introduces a new framework called Class Extension with Limited
Data (CELD) to train a classifier to categorize retinal fundus images. The
classifier is initially trained to identify relevant features concerning
Healthy and Diabetic Retinopathy (DR) classes and later fine-tuned to adapt to
the task of classifying the input images into three classes: Healthy, DR, and
Glaucoma. This strategy allows the model to gradually enhance its
classification capabilities, which is beneficial in situations where there are
only a limited number of labeled datasets available. Perturbation methods are
also used to identify the input image characteristics responsible for
influencing the models decision-making process. We achieve an overall accuracy
of 91% on publicly available datasets.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on medical applications of AI (diabetic disorders in eye images), which is explicitly listed as a rejection criterion.

---

## [Teacher Encoder-Student Decoder Denoising Guided Segmentation Network
  for Anomaly Detection](https://arxiv.org/abs/2501.12104v1)
**arXiv ID:** 2501.12104v1

**Abstract:**
> Visual anomaly detection is a highly challenging task, often categorized as a
one-class classification and segmentation problem. Recent studies have
demonstrated that the student-teacher (S-T) framework effectively addresses
this challenge. However, most S-T frameworks rely solely on pre-trained teacher
networks to guide student networks in learning multi-scale similar features,
overlooking the potential of the student networks to enhance learning through
multi-scale feature fusion. In this study, we propose a novel model named
PFADSeg, which integrates a pre-trained teacher network, a denoising student
network with multi-scale feature fusion, and a guided anomaly segmentation
network into a unified framework. By adopting a unique teacher-encoder and
student-decoder denoising mode, the model improves the student network's
ability to learn from teacher network features. Furthermore, an adaptive
feature fusion mechanism is introduced to train a self-supervised segmentation
network that synthesizes anomaly masks autonomously, significantly increasing
detection performance. Evaluated on the MVTec AD dataset, PFADSeg achieves
state-of-the-art results with an image-level AUC of 98.9%, a pixel-level mean
precision of 76.4%, and an instance-level mean precision of 78.7%.

**Decision Explanation:** Original decision: REJECT
The paper does not meet the required criteria as it focuses on visual anomaly detection using a student-teacher framework, without any indication of involving Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, which are the core areas of interest.

---

## [Can open source large language models be used for tumor documentation in
  Germany? -- An evaluation on urological doctors' notes](https://arxiv.org/abs/2501.12106v1)
**arXiv ID:** 2501.12106v1

**Abstract:**
> Tumor documentation in Germany is largely done manually, requiring reading
patient records and entering data into structured databases. Large language
models (LLMs) could potentially enhance this process by improving efficiency
and reliability. This evaluation tests eleven different open source LLMs with
sizes ranging from 1-70 billion model parameters on three basic tasks of the
tumor documentation process: identifying tumor diagnoses, assigning ICD-10
codes, and extracting the date of first diagnosis. For evaluating the LLMs on
these tasks, a dataset of annotated text snippets based on anonymized doctors'
notes from urology was prepared. Different prompting strategies were used to
investigate the effect of the number of examples in few-shot prompting and to
explore the capabilities of the LLMs in general. The models Llama 3.1 8B,
Mistral 7B, and Mistral NeMo 12 B performed comparably well in the tasks.
Models with less extensive training data or having fewer than 7 billion
parameters showed notably lower performance, while larger models did not
display performance gains. Examples from a different medical domain than
urology could also improve the outcome in few-shot prompting, which
demonstrates the ability of LLMs to handle tasks needed for tumor
documentation. Open source LLMs show a strong potential for automating tumor
documentation. Models from 7-12 billion parameters could offer an optimal
balance between performance and resource efficiency. With tailored fine-tuning
and well-designed prompting, these models might become important tools for
clinical documentation in the future. The code for the evaluation is available
from https://github.com/stefan-m-lenz/UroLlmEval. We also release the dataset
as a new valuable resource that addresses the shortage of authentic and easily
accessible benchmarks in German-language medical NLP.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on medical applications of AI (tumor documentation in Germany), which is an exclusion criterion as per the evaluation guidelines.

---

## [FedCLEAN: byzantine defense by CLustering Errors of Activation maps in
  Non-IID federated learning environments](https://arxiv.org/abs/2501.12123v1)
**arXiv ID:** 2501.12123v1

**Abstract:**
> Federated Learning (FL) enables clients to collaboratively train a global
model using their local datasets while reinforcing data privacy. However, FL is
susceptible to poisoning attacks. Existing defense mechanisms assume that
clients' data are independent and identically distributed (IID), making them
ineffective in real-world applications where data are non-IID. This paper
presents FedCLEAN, the first defense capable of filtering attackers' model
updates in a non-IID FL environment. The originality of FedCLEAN is twofold.
First, it relies on a client confidence score derived from the reconstruction
errors of each client's model activation maps for a given trigger set, with
reconstruction errors obtained by means of a Conditional Variational
Autoencoder trained according to a novel server-side strategy. Second, we
propose an ad-hoc trust propagation algorithm based on client scores, which
allows building a cluster of benign clients while flagging potential attackers.
Experimental results on the datasets MNIST and FashionMNIST demonstrate the
robustness of FedCLEAN against Byzantine attackers in non-IID scenarios and a
close-to-zero benign client misclassification rate, even in the absence of an
attack.

**Decision Explanation:** Original decision: REJECT
The paper does not meet the primary criteria as it focuses on federated learning (FL) and defense mechanisms against poisoning attacks, without apparent involvement or application of Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, which are the core areas of interest.

---

## [FuocChuVIP123 at CoMeDi Shared Task: Disagreement Ranking with
  XLM-Roberta Sentence Embeddings and Deep Neural Regression](https://arxiv.org/abs/2501.12336v1)
**arXiv ID:** 2501.12336v1

**Abstract:**
> This paper presents results of our system for CoMeDi Shared Task, focusing on
Subtask 2: Disagreement Ranking. Our system leverages sentence embeddings
generated by the paraphrase-xlm-r-multilingual-v1 model, combined with a deep
neural regression model incorporating batch normalization and dropout for
improved generalization. By predicting the mean of pairwise judgment
differences between annotators, our method explicitly targets disagreement
ranking, diverging from traditional "gold label" aggregation approaches. We
optimized our system with a customized architecture and training procedure,
achieving competitive performance in Spearman correlation against mean
disagreement labels. Our results highlight the importance of robust embeddings,
effective model architecture, and careful handling of judgment differences for
ranking disagreement in multilingual contexts. These findings provide insights
into the use of contextualized representations for ordinal judgment tasks and
open avenues for further refinement of disagreement prediction models.

**Decision Explanation:** Original response: ```
{
    "decision": "REJECT",
    "explanation": "The paper does not meet the primary criteria for Practical Applications in areas like knowledge graphs, retrieval-augmented generation (RAG), or agentic AI. It also doesn't clearly align with other key criteria, focusing instead on disagreement ranking with sentence embeddings, which is not explicitly mentioned as a priority area in the evaluation guidelines."
}
```

---

## [Video Depth Anything: Consistent Depth Estimation for Super-Long Videos](https://arxiv.org/abs/2501.12375v1)
**arXiv ID:** 2501.12375v1

**Abstract:**
> Depth Anything has achieved remarkable success in monocular depth estimation
with strong generalization ability. However, it suffers from temporal
inconsistency in videos, hindering its practical applications. Various methods
have been proposed to alleviate this issue by leveraging video generation
models or introducing priors from optical flow and camera poses. Nonetheless,
these methods are only applicable to short videos (< 10 seconds) and require a
trade-off between quality and computational efficiency. We propose Video Depth
Anything for high-quality, consistent depth estimation in super-long videos
(over several minutes) without sacrificing efficiency. We base our model on
Depth Anything V2 and replace its head with an efficient spatial-temporal head.
We design a straightforward yet effective temporal consistency loss by
constraining the temporal depth gradient, eliminating the need for additional
geometric priors. The model is trained on a joint dataset of video depth and
unlabeled images, similar to Depth Anything V2. Moreover, a novel
key-frame-based strategy is developed for long video inference. Experiments
show that our model can be applied to arbitrarily long videos without
compromising quality, consistency, or generalization ability. Comprehensive
evaluations on multiple video benchmarks demonstrate that our approach sets a
new state-of-the-art in zero-shot video depth estimation. We offer models of
different scales to support a range of scenarios, with our smallest model
capable of real-time performance at 30 FPS.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on video processing, specifically depth estimation in super-long videos, which is explicitly listed as a rejection criterion.

---

## [Leveraging GANs For Active Appearance Models Optimized Model Fitting](https://arxiv.org/abs/2501.11218v1)
**arXiv ID:** 2501.11218v1

**Abstract:**
> Generative Adversarial Networks (GANs) have gained prominence in refining
model fitting tasks in computer vision, particularly in domains involving
deformable models like Active Appearance Models (AAMs). This paper explores the
integration of GANs to enhance the AAM fitting process, addressing challenges
in optimizing nonlinear parameters associated with appearance and shape
variations. By leveraging GANs' adversarial training framework, the aim is to
minimize fitting errors and improve convergence rates. Achieving robust
performance even in cases with high appearance variability and occlusions. Our
approach demonstrates significant improvements in accuracy and computational
efficiency compared to traditional optimization techniques, thus establishing
GANs as a potent tool for advanced image model fitting.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on computer vision (image model fitting) using GANs, with no apparent connection to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, thus failing to meet the core selection criteria.

---

## [WSSM: Geographic-enhanced hierarchical state-space model for global
  station weather forecast](https://arxiv.org/abs/2501.11238v1)
**arXiv ID:** 2501.11238v1

**Abstract:**
> Global Station Weather Forecasting (GSWF), a prominent meteorological
research area, is pivotal in providing timely localized weather predictions.
Despite the progress existing models have made in the overall accuracy of the
GSWF, executing high-precision extreme event prediction still presents a
substantial challenge. The recent emergence of state-space models, with their
ability to efficiently capture continuous-time dynamics and latent states,
offer potential solutions. However, early investigations indicated that Mamba
underperforms in the context of GSWF, suggesting further adaptation and
optimization. To tackle this problem, in this paper, we introduce Weather
State-space Model (WSSM), a novel Mamba-based approach tailored for GSWF.
Geographical knowledge is integrated in addition to the widely-used positional
encoding to represent the absolute special-temporal position. The multi-scale
time-frequency features are synthesized from coarse to fine to model the
seasonal to extreme weather dynamic. Our method effectively improves the
overall prediction accuracy and addresses the challenge of forecasting extreme
weather events. The state-of-the-art results obtained on the Weather-5K subset
underscore the efficacy of the WSSM

**Decision Explanation:** Original decision: REJECT
The paper does not meet the required criteria as it primarily focuses on weather forecasting, a domain unrelated to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, with no mention of LLMs or relevant AI technologies.

---

## [Spatiotemporal Air Quality Mapping in Urban Areas Using Sparse Sensor
  Data, Satellite Imagery, Meteorological Factors, and Spatial Features](https://arxiv.org/abs/2501.11270v1)
**arXiv ID:** 2501.11270v1

**Abstract:**
> Monitoring air pollution is crucial for protecting human health from exposure
to harmful substances. Traditional methods of air quality monitoring, such as
ground-based sensors and satellite-based remote sensing, face limitations due
to high deployment costs, sparse sensor coverage, and environmental
interferences. To address these challenges, this paper proposes a framework for
high-resolution spatiotemporal Air Quality Index (AQI) mapping using sparse
sensor data, satellite imagery, and various spatiotemporal factors. By
leveraging Graph Neural Networks (GNNs), we estimate AQI values at unmonitored
locations based on both spatial and temporal dependencies. The framework
incorporates a wide range of environmental features, including meteorological
data, road networks, points of interest (PoIs), population density, and urban
green spaces, which enhance prediction accuracy. We illustrate the use of our
approach through a case study in Lahore, Pakistan, where multi-resolution data
is used to generate the air quality index map at a fine spatiotemporal scale.

**Decision Explanation:** Original decision: REJECT
The paper does not meet the primary criteria as it does not focus on Large Language Models (LLMs) or related areas like knowledge graphs, retrieval-augmented generation (RAG), or agentic AI. Instead, it leverages Graph Neural Networks (GNNs) for spatiotemporal air quality mapping, which does not align with the specified topics of interest.

---

## [A Machine Learning Framework for Handling Unreliable Absence Label and
  Class Imbalance for Marine Stinger Beaching Prediction](https://arxiv.org/abs/2501.11293v1)
**arXiv ID:** 2501.11293v1

**Abstract:**
> Bluebottles (\textit{Physalia} spp.) are marine stingers resembling
jellyfish, whose presence on Australian beaches poses a significant public risk
due to their venomous nature. Understanding the environmental factors driving
bluebottles ashore is crucial for mitigating their impact, and machine learning
tools are to date relatively unexplored. We use bluebottle marine stinger
presence/absence data from beaches in Eastern Sydney, Australia, and compare
machine learning models (Multilayer Perceptron, Random Forest, and XGBoost) to
identify factors influencing their presence. We address challenges such as
class imbalance, class overlap, and unreliable absence data by employing data
augmentation techniques, including the Synthetic Minority Oversampling
Technique (SMOTE), Random Undersampling, and Synthetic Negative Approach that
excludes the negative class. Our results show that SMOTE failed to resolve
class overlap, but the presence-focused approach effectively handled imbalance,
class overlap, and ambiguous absence data. The data attributes such as the wind
direction, which is a circular variable, emerged as a key factor influencing
bluebottle presence, confirming previous inference studies. However, in the
absence of population dynamics, biological behaviours, and life cycles, the
best predictive model appears to be Random Forests combined with Synthetic
Negative Approach. This research contributes to mitigating the risks posed by
bluebottles to beachgoers and provides insights into handling class overlap and
unreliable negative class in environmental modelling.

**Decision Explanation:** Original decision: REJECT
The paper does not meet any of the required criteria (1-3) as it does not focus on Large Language Models (LLMs), lacks experimental results with quantitative metrics related to LLMs, and does not compare with state-of-the-art LLM techniques. Additionally, its primary focus on environmental modelling for marine stinger beaching prediction falls outside the specified rejection criteria, but more importantly, does not align with the paper selection criteria.

---

## [On the Dimension of Pullback Attractors in Recurrent Neural Networks](https://arxiv.org/abs/2501.11357v1)
**arXiv ID:** 2501.11357v1

**Abstract:**
> Recurrent Neural Networks (RNNs) are high-dimensional state space models
capable of learning functions on sequence data. Recently, it has been
conjectured that reservoir computers, a particular class of RNNs, trained on
observations of a dynamical systems can be interpreted as embeddings. This
result has been established for the case of linear reservoir systems. In this
work, we use a nonautonomous dynamical systems approach to establish an upper
bound for the fractal dimension of the subset of reservoir state space
approximated during training and prediction phase. We prove that when the input
sequences comes from an Nin-dimensional invertible dynamical system, the
fractal dimension of this set is bounded above by Nin. The result obtained here
are useful in dimensionality reduction of computation in RNNs as well as
estimating fractal dimensions of dynamical systems from limited observations of
their time series. It is also a step towards understanding embedding properties
of reservoir computers.

**Decision Explanation:** Original decision: REJECT
The paper does not meet any of the required criteria, specifically lacking focus on Large Language Models (LLMs), practical applications in knowledge graphs, RAG, or agentic AI, and instead centers on Recurrent Neural Networks (RNNs) and dynamical systems, which are outside the specified scope.

---

## [Investigation of Whisper ASR Hallucinations Induced by Non-Speech Audio](https://arxiv.org/abs/2501.11378v1)
**arXiv ID:** 2501.11378v1

**Abstract:**
> Hallucinations of deep neural models are amongst key challenges in automatic
speech recognition (ASR). In this paper, we investigate hallucinations of the
Whisper ASR model induced by non-speech audio segments present during
inference. By inducting hallucinations with various types of sounds, we show
that there exists a set of hallucinations that appear frequently. We then study
hallucinations caused by the augmentation of speech with such sounds. Finally,
we describe the creation of a bag of hallucinations (BoH) that allows to remove
the effect of hallucinations through the post-processing of text
transcriptions. The results of our experiments show that such post-processing
is capable of reducing word error rate (WER) and acts as a good safeguard
against problematic hallucinations.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on Automatic Speech Recognition (ASR) and audio processing, with no clear connection to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, failing to meet the fundamental criteria for practical applications of LLMs.

---

## [A Truly Sparse and General Implementation of Gradient-Based Synaptic
  Plasticity](https://arxiv.org/abs/2501.11407v1)
**arXiv ID:** 2501.11407v1

**Abstract:**
> Online synaptic plasticity rules derived from gradient descent achieve high
accuracy on a wide range of practical tasks. However, their software
implementation often requires tediously hand-derived gradients or using
gradient backpropagation which sacrifices the online capability of the rules.
In this work, we present a custom automatic differentiation (AD) pipeline for
sparse and online implementation of gradient-based synaptic plasticity rules
that generalizes to arbitrary neuron models. Our work combines the programming
ease of backpropagation-type methods for forward AD while being
memory-efficient. To achieve this, we exploit the advantageous compute and
memory scaling of online synaptic plasticity by providing an inherently sparse
implementation of AD where expensive tensor contractions are replaced with
simple element-wise multiplications if the tensors are diagonal. Gradient-based
synaptic plasticity rules such as eligibility propagation (e-prop) have exactly
this property and thus profit immensely from this feature. We demonstrate the
alignment of our gradients with respect to gradient backpropagation on an
synthetic task where e-prop gradients are exact, as well as audio speech
classification benchmarks. We demonstrate how memory utilization scales with
network size without dependence on the sequence length, as expected from
forward AD methods.

**Decision Explanation:** Original decision: REJECT
The paper does not meet any of the mandatory criteria (1-3) as it focuses on synaptic plasticity and neural networks rather than Large Language Models (LLMs), and does not discuss practical applications, experimental results, or comparisons to state-of-the-art in the context of LLMs. Additionally, it does not align with any of the preferred criteria (4-5) related to LLMs, knowledge graphs, retrieval-augmented generation, or agentic AI.

---

## [Generalization and Informativeness of Weighted Conformal Risk Control
  Under Covariate Shift](https://arxiv.org/abs/2501.11413v1)
**arXiv ID:** 2501.11413v1

**Abstract:**
> Predictive models are often required to produce reliable predictions under
statistical conditions that are not matched to the training data. A common type
of training-testing mismatch is covariate shift, where the conditional
distribution of the target variable given the input features remains fixed,
while the marginal distribution of the inputs changes. Weighted conformal risk
control (W-CRC) uses data collected during the training phase to convert point
predictions into prediction sets with valid risk guarantees at test time
despite the presence of a covariate shift. However, while W-CRC provides
statistical reliability, its efficiency -- measured by the size of the
prediction sets -- can only be assessed at test time. In this work, we relate
the generalization properties of the base predictor to the efficiency of W-CRC
under covariate shifts. Specifically, we derive a bound on the inefficiency of
the W-CRC predictor that depends on algorithmic hyperparameters and
task-specific quantities available at training time. This bound offers insights
on relationships between the informativeness of the prediction sets, the extent
of the covariate shift, and the size of the calibration and training sets.
Experiments on fingerprinting-based localization validate the theoretical
results.

**Decision Explanation:** Original decision: REJECT
The paper does not meet any of the required criteria, focusing on predictive model reliability under covariate shift without mentioning Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, and lacking clear connections to practical applications of LLMs as specified in the criteria.

---

## [Enhancing Coronary Artery Calcium Scoring via Multi-Organ Segmentation
  on Non-Contrast Cardiac Computed Tomography](https://arxiv.org/abs/2501.11428v1)
**arXiv ID:** 2501.11428v1

**Abstract:**
> Despite coronary artery calcium scoring being considered a largely solved
problem within the realm of medical artificial intelligence, this paper argues
that significant improvements can still be made. By shifting the focus from
pathology detection to a deeper understanding of anatomy, the novel algorithm
proposed in the paper both achieves high accuracy in coronary artery calcium
scoring and offers enhanced interpretability of the results. This approach not
only aids in the precise quantification of calcifications in coronary arteries,
but also provides valuable insights into the underlying anatomical structures.
Through this anatomically-informed methodology, the paper shows how a nuanced
understanding of the heart's anatomy can lead to more accurate and
interpretable results in the field of cardiovascular health. We demonstrate the
superior accuracy of the proposed method by evaluating it on an open-source
multi-vendor dataset, where we obtain results at the inter-observer level,
surpassing the current state of the art. Finally, the qualitative analyses show
the practical value of the algorithm in such tasks as labeling coronary artery
calcifications, identifying aortic calcifications, and filtering out false
positive detections due to noise.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on medical applications of AI, specifically cardiovascular health, which is explicitly mentioned as a rejection criterion.

---

## [Decomposing Interventional Causality into Synergistic, Redundant, and
  Unique Components](https://arxiv.org/abs/2501.11447v1)
**arXiv ID:** 2501.11447v1

**Abstract:**
> We introduce a novel framework for decomposing interventional causal effects
into synergistic, redundant, and unique components, building on the intuition
of Partial Information Decomposition (PID) and the principle of M\"obius
inversion. While recent work has explored a similar decomposition of an
observational measure, we argue that a proper causal decomposition must be
interventional in nature. We develop a mathematical approach that
systematically quantifies how causal power is distributed among variables in a
system, using a recently derived closed-form expression for the M\"obius
function of the redundancy lattice. The formalism is then illustrated by
decomposing the causal power in logic gates, cellular automata, and chemical
reaction networks. Our results reveal how the distribution of causal power can
be context- and parameter-dependent. This decomposition provides new insights
into complex systems by revealing how causal influences are shared and combined
among multiple variables, with potential applications ranging from attribution
of responsibility in legal or AI systems, to the analysis of biological
networks or climate models.

**Decision Explanation:** Original decision: REJECT
The paper does not meet any of the mandatory criteria (1-3) as it lacks focus on Large Language Models (LLMs), experimental results with quantitative metrics, and comparison with state-of-the-art techniques. Additionally, its primary focus on causal decomposition in complex systems, with potential applications in legal systems, does not align with the criteria, and its potential application in AI systems is too broad and not specifically related to LLMs or the specified areas.

---

## [Generative AI and Large Language Models in Language Preservation:
  Opportunities and Challenges](https://arxiv.org/abs/2501.11496v1)
**arXiv ID:** 2501.11496v1

**Abstract:**
> Generative AI and large-scale language models (LLM) have emerged as powerful
tools in language preservation, particularly for near-native and endangered
languages. With the increasing reliance on technology for communication,
education, and cultural documentation, new opportunities have emerged to
mitigate the dramatic decline of linguistic diversity worldwide. This paper
examines the role of generative AIs and LLMs in preserving endangered
languages, highlighting the risks and challenges associated with their use. We
analyze the underlying technologies driving these models, including natural
language processing (NLP) and deep learning, and explore several cases where
these technologies have been applied to low-resource languages. Additionally,
we discuss ethical considerations, data scarcity issues, and technical
challenges while proposing solutions to enhance AI-driven language
preservation.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on social applications of AI in regard to linguistic diversity and cultural preservation, which aligns with rejected criteria related to social applications of AI, warranting rejection despite potential novelty in language preservation.

---

## [Dialect2SQL: A Novel Text-to-SQL Dataset for Arabic Dialects with a
  Focus on Moroccan Darija](https://arxiv.org/abs/2501.11498v1)
**arXiv ID:** 2501.11498v1

**Abstract:**
> The task of converting natural language questions (NLQs) into executable SQL
queries, known as text-to-SQL, has gained significant interest in recent years,
as it enables non-technical users to interact with relational databases. Many
benchmarks, such as SPIDER and WikiSQL, have contributed to the development of
new models and the evaluation of their performance. In addition, other
datasets, like SEDE and BIRD, have introduced more challenges and complexities
to better map real-world scenarios. However, these datasets primarily focus on
high-resource languages such as English and Chinese. In this work, we introduce
Dialect2SQL, the first large-scale, cross-domain text-to-SQL dataset in an
Arabic dialect. It consists of 9,428 NLQ-SQL pairs across 69 databases in
various domains. Along with SQL-related challenges such as long schemas, dirty
values, and complex queries, our dataset also incorporates the complexities of
the Moroccan dialect, which is known for its diverse source languages, numerous
borrowed words, and unique expressions. This demonstrates that our dataset will
be a valuable contribution to both the text-to-SQL community and the
development of resources for low-resource languages.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on developing a text-to-SQL dataset for an Arabic dialect, without explicit mention of Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, failing to meet the mandatory criteria.

---

## [Technical Report for the Forgotten-by-Design Project: Targeted
  Obfuscation for Machine Learning](https://arxiv.org/abs/2501.11525v1)
**arXiv ID:** 2501.11525v1

**Abstract:**
> The right to privacy, enshrined in various human rights declarations, faces
new challenges in the age of artificial intelligence (AI). This paper explores
the concept of the Right to be Forgotten (RTBF) within AI systems, contrasting
it with traditional data erasure methods. We introduce Forgotten by Design, a
proactive approach to privacy preservation that integrates instance-specific
obfuscation techniques during the AI model training process. Unlike machine
unlearning, which modifies models post-training, our method prevents sensitive
data from being embedded in the first place. Using the LIRA membership
inference attack, we identify vulnerable data points and propose defenses that
combine additive gradient noise and weighting schemes. Our experiments on the
CIFAR-10 dataset demonstrate that our techniques reduce privacy risks by at
least an order of magnitude while maintaining model accuracy (at 95%
significance). Additionally, we present visualization methods for the
privacy-utility trade-off, providing a clear framework for balancing privacy
risk and model accuracy. This work contributes to the development of
privacy-preserving AI systems that align with human cognitive processes of
motivated forgetting, offering a robust framework for safeguarding sensitive
information and ensuring compliance with privacy regulations.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on responsible AI application (privacy preservation and compliance with privacy regulations), which is explicitly listed as a rejection criterion, outweighing its marginal relevance to Large Language Models (LLMs) through its broader AI context.

---

## [Training-free Ultra Small Model for Universal Sparse Reconstruction in
  Compressed Sensing](https://arxiv.org/abs/2501.11592v1)
**arXiv ID:** 2501.11592v1

**Abstract:**
> Pre-trained large models attract widespread attention in recent years, but
they face challenges in applications that require high interpretability or have
limited resources, such as physical sensing, medical imaging, and
bioinformatics. Compressed Sensing (CS) is a well-proved theory that drives
many recent breakthroughs in these applications. However, as a typical
under-determined linear system, CS suffers from excessively long sparse
reconstruction times when using traditional iterative methods, particularly
with large-scale data. Current AI methods like deep unfolding fail to
substitute them because pre-trained models exhibit poor generality beyond their
training conditions and dataset distributions, or lack interpretability.
Instead of following the big model fervor, this paper proposes ultra-small
artificial neural models called coefficients learning (CL), enabling
training-free and rapid sparse reconstruction while perfectly inheriting the
generality and interpretability of traditional iterative methods, bringing new
feature of incorporating prior knowledges. In CL, a signal of length $n$ only
needs a minimal of $n$ trainable parameters. A case study model called CLOMP is
implemented for evaluation. Experiments are conducted on both synthetic and
real one-dimensional and two-dimensional signals, demonstrating significant
improvements in efficiency and accuracy. Compared to representative iterative
methods, CLOMP improves efficiency by 100 to 1000 folds for large-scale data.
Test results on eight diverse image datasets indicate that CLOMP improves
structural similarity index by 292%, 98%, 45% for sampling rates of 0.1, 0.3,
0.5, respectively. We believe this method can truly usher CS reconstruction
into the AI era, benefiting countless under-determined linear systems that rely
on sparse solution.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on Compressed Sensing for applications in physical sensing, medical imaging, and bioinformatics, which aligns with excluded topics (medical applications of AI and not explicitly focusing on Large Language Models or related areas like knowledge graphs, RAG, or agentic AI).

---

## [Fairness Testing through Extreme Value Theory](https://arxiv.org/abs/2501.11597v1)
**arXiv ID:** 2501.11597v1

**Abstract:**
> Data-driven software is increasingly being used as a critical component of
automated decision-support systems. Since this class of software learns its
logic from historical data, it can encode or amplify discriminatory practices.
Previous research on algorithmic fairness has focused on improving average-case
fairness. On the other hand, fairness at the extreme ends of the spectrum,
which often signifies lasting and impactful shifts in societal attitudes, has
received significantly less emphasis.
  Leveraging the statistics of extreme value theory (EVT), we propose a novel
fairness criterion called extreme counterfactual discrimination (ECD). This
criterion estimates the worst-case amounts of disadvantage in outcomes for
individuals solely based on their memberships in a protected group. Utilizing
tools from search-based software engineering and generative AI, we present a
randomized algorithm that samples a statistically significant set of points
from the tail of ML outcome distributions even if the input dataset lacks a
sufficient number of relevant samples.
  We conducted several experiments on four ML models (deep neural networks,
logistic regression, and random forests) over 10 socially relevant tasks from
the literature on algorithmic fairness. First, we evaluate the generative AI
methods and find that they generate sufficient samples to infer valid EVT
distribution in 95% of cases. Remarkably, we found that the prevalent bias
mitigators reduce the average-case discrimination but increase the worst-case
discrimination significantly in 5% of cases. We also observed that even the
tail-aware mitigation algorithm -- MiniMax-Fairness -- increased the worst-case
discrimination in 30% of cases. We propose a novel ECD-based mitigator that
improves fairness in the tail in 90% of cases with no degradation of the
average-case discrimination.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on fairness and bias in AI decision-making systems, which aligns with "responsible AI application or AI ethics", a criterion for rejection. It also lacks clear connections to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI as specified in the selection criteria.

---

## [Noise-Agnostic Multitask Whisper Training for Reducing False Alarm
  Errors in Call-for-Help Detection](https://arxiv.org/abs/2501.11631v1)
**arXiv ID:** 2501.11631v1

**Abstract:**
> Keyword spotting is often implemented by keyword classifier to the encoder in
acoustic models, enabling the classification of predefined or open vocabulary
keywords. Although keyword spotting is a crucial task in various applications
and can be extended to call-for-help detection in emergencies, however, the
previous method often suffers from scalability limitations due to retraining
required to introduce new keywords or adapt to changing contexts. We explore a
simple yet effective approach that leverages off-the-shelf pretrained ASR
models to address these challenges, especially in call-for-help detection
scenarios. Furthermore, we observed a substantial increase in false alarms when
deploying call-for-help detection system in real-world scenarios due to noise
introduced by microphones or different environments. To address this, we
propose a novel noise-agnostic multitask learning approach that integrates a
noise classification head into the ASR encoder. Our method enhances the model's
robustness to noisy environments, leading to a significant reduction in false
alarms and improved overall call-for-help performance. Despite the added
complexity of multitask learning, our approach is computationally efficient and
provides a promising solution for call-for-help detection in real-world
scenarios.

**Decision Explanation:** Original response: ```
{
    "decision": "REJECT",
    "explanation": "The paper primarily focuses on acoustic models, automatic speech recognition (ASR), and noise reduction in call-for-help detection, which does not align with the specified criteria emphasizing Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI. Its applications and methodologies fall outside the designated scope."
}
```

---

## [Biomedical Knowledge Graph: A Survey of Domains, Tasks, and Real-World
  Applications](https://arxiv.org/abs/2501.11632v1)
**arXiv ID:** 2501.11632v1

**Abstract:**
> Biomedical knowledge graphs (BKGs) have emerged as powerful tools for
organizing and leveraging the vast and complex data found across the biomedical
field. Yet, current reviews of BKGs often limit their scope to specific domains
or methods, overlooking the broader landscape and the rapid technological
progress reshaping it. In this survey, we address this gap by offering a
systematic review of BKGs from three core perspectives: domains, tasks, and
applications. We begin by examining how BKGs are constructed from diverse data
sources, including molecular interactions, pharmacological datasets, and
clinical records. Next, we discuss the essential tasks enabled by BKGs,
focusing on knowledge management, retrieval, reasoning, and interpretation.
Finally, we highlight real-world applications in precision medicine, drug
discovery, and scientific research, illustrating the translational impact of
BKGs across multiple sectors. By synthesizing these perspectives into a unified
framework, this survey not only clarifies the current state of BKG research but
also establishes a foundation for future exploration, enabling both innovative
methodological advances and practical implementations.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on biomedical applications, which is excluded according to the rejection criteria, specifically the focus on medical applications of AI.

---

## [Transformer Vibration Forecasting for Advancing Rail Safety and
  Maintenance 4.0](https://arxiv.org/abs/2501.11730v1)
**arXiv ID:** 2501.11730v1

**Abstract:**
> Maintaining railway axles is critical to preventing severe accidents and
financial losses. The railway industry is increasingly interested in advanced
condition monitoring techniques to enhance safety and efficiency, moving beyond
traditional periodic inspections toward Maintenance 4.0.
  This study introduces a robust Deep Autoregressive solution that integrates
seamlessly with existing systems to avert mechanical failures. Our approach
simulates and predicts vibration signals under various conditions and fault
scenarios, improving dataset robustness for more effective detection systems.
These systems can alert maintenance needs, preventing accidents preemptively.
We use experimental vibration signals from accelerometers on train axles.
  Our primary contributions include a transformer model, ShaftFormer, designed
for processing time series data, and an alternative model incorporating
spectral methods and enhanced observation models. Simulating vibration signals
under diverse conditions mitigates the high cost of obtaining experimental
signals for all scenarios. Given the non-stationary nature of railway vibration
signals, influenced by speed and load changes, our models address these
complexities, offering a powerful tool for predictive maintenance in the rail
industry.

**Decision Explanation:** Original response: ```
{
    "decision": "REJECT",
    "explanation": "The paper primarily focuses on predictive maintenance in the rail industry, utilizing a transformer model for vibration forecasting, but does not indicate the use of Large Language Models (LLMs) as required by the selection criteria, nor does it mention applications in knowledge graphs, retrieval-augmented generation, or agentic AI."
}
```

---

## [SILO: Solving Inverse Problems with Latent Operators](https://arxiv.org/abs/2501.11746v1)
**arXiv ID:** 2501.11746v1

**Abstract:**
> Consistent improvement of image priors over the years has led to the
development of better inverse problem solvers. Diffusion models are the
newcomers to this arena, posing the strongest known prior to date. Recently,
such models operating in a latent space have become increasingly predominant
due to their efficiency. In recent works, these models have been applied to
solve inverse problems. Working in the latent space typically requires multiple
applications of an Autoencoder during the restoration process, which leads to
both computational and restoration quality challenges. In this work, we propose
a new approach for handling inverse problems with latent diffusion models,
where a learned degradation function operates within the latent space,
emulating a known image space degradation. Usage of the learned operator
reduces the dependency on the Autoencoder to only the initial and final steps
of the restoration process, facilitating faster sampling and superior
restoration quality. We demonstrate the effectiveness of our method on a
variety of image restoration tasks and datasets, achieving significant
improvements over prior art.

**Decision Explanation:** Original decision: REJECT
The paper does not meet the required criteria as it primarily focuses on image restoration tasks using diffusion models and autoencoders, with no evident connection to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI.

---

## [Policy-Adaptable Methods For Resolving Normative Conflicts Through
  Argumentation and Graph Colouring](https://arxiv.org/abs/2501.11799v1)
**arXiv ID:** 2501.11799v1

**Abstract:**
> In a multi-agent system, one may choose to govern the behaviour of an agent
by imposing norms, which act as guidelines for how agents should act either all
of the time or in given situations. However, imposing multiple norms on one or
more agents may result in situations where these norms conflict over how the
agent should behave. In any system with normative conflicts (such as safe
reinforcement models or systems which monitor safety protocols), one must
decide which norms should be followed such that the most important and most
relevant norms are maintained. We introduce a new method for resolving
normative conflicts through argumentation and graph colouring which is
compatible with a variety of normative conflict resolution policies. We prove
that this method always creates an admissible set of arguments under
argumentation semantics, meaning that it produces coherent outputs. We also
introduce more robust variants of this method, each building upon their
predecessor to create a superior output, and we include further mathematical
proof of their coherence. Our most advanced variant uses the existing concept
of curtailment, where one norm may supersede another without fully eliminating
it. The methods we introduce are all compatible with various pre-existing
policies for resolving normative conflicts. Empirical evaluations are also
performed to compare our algorithms to each other and to others in existing
literature.

**Decision Explanation:** Original response: ```
{
    "decision": "REJECT",
    "explanation": "The paper does not explicitly mention Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, which are the primary focus areas. It focuses on normative conflicts resolution in multi-agent systems using argumentation and graph coloring, which doesn't meet the mandatory criteria (1, 2, and 3) and doesn't explicitly align with any of the additional considerations."
}
```

---

## [Toward Effective Digraph Representation Learning: A Magnetic Adaptive
  Propagation based Approach](https://arxiv.org/abs/2501.11817v1)
**arXiv ID:** 2501.11817v1

**Abstract:**
> The $q$-parameterized magnetic Laplacian serves as the foundation of directed
graph (digraph) convolution, enabling this kind of digraph neural network
(MagDG) to encode node features and structural insights by complex-domain
message passing. As a generalization of undirected methods, MagDG shows
superior capability in modeling intricate web-scale topology. Despite the great
success achieved by existing MagDGs, limitations still exist: (1) Hand-crafted
$q$: The performance of MagDGs depends on selecting an appropriate
$q$-parameter to construct suitable graph propagation equations in the complex
domain. This parameter tuning, driven by downstream tasks, limits model
flexibility and significantly increases manual effort. (2) Coarse Message
Passing: Most approaches treat all nodes with the same complex-domain
propagation and aggregation rules, neglecting their unique digraph contexts.
This oversight results in sub-optimal performance. To address the above issues,
we propose two key techniques: (1) MAP is crafted to be a plug-and-play
complex-domain propagation optimization strategy in the context of digraph
learning, enabling seamless integration into any MagDG to improve predictions
while enjoying high running efficiency. (2) MAP++ is a new digraph learning
framework, further incorporating a learnable mechanism to achieve adaptively
edge-wise propagation and node-wise aggregation in the complex domain for
better performance. Extensive experiments on 12 datasets demonstrate that MAP
enjoys flexibility for it can be incorporated with any MagDG, and scalability
as it can deal with web-scale digraphs. MAP++ achieves SOTA predictive
performance on 4 different downstream tasks.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on digraph representation learning and graph neural networks, without mentioning Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, thus failing to meet the mandatory criteria related to LLMs.

---

## [Toward Scalable Graph Unlearning: A Node Influence Maximization based
  Approach](https://arxiv.org/abs/2501.11823v1)
**arXiv ID:** 2501.11823v1

**Abstract:**
> Machine unlearning, as a pivotal technology for enhancing model robustness
and data privacy, has garnered significant attention in prevalent web mining
applications, especially in thriving graph-based scenarios. However, most
existing graph unlearning (GU) approaches face significant challenges due to
the intricate interactions among web-scale graph elements during the model
training: (1) The gradient-driven node entanglement hinders the complete
knowledge removal in response to unlearning requests; (2) The billion-level
graph elements in the web scenarios present inevitable scalability issues. To
break the above limitations, we open up a new perspective by drawing a
connection between GU and conventional social influence maximization. To this
end, we propose Node Influence Maximization (NIM) through the decoupled
influence propagation model and fine-grained influence function in a scalable
manner, which is crafted to be a plug-and-play strategy to identify potential
nodes affected by unlearning entities. This approach enables offline execution
independent of GU, allowing it to be seamlessly integrated into most GU methods
to improve their unlearning performance. Based on this, we introduce Scalable
Graph Unlearning (SGU) as a new fine-tuned framework, which balances the
forgetting and reasoning capability of the unlearned model by entity-specific
optimizations. Extensive experiments on 14 datasets, including large-scale
ogbn-papers100M, have demonstrated the effectiveness of our approach.
Specifically, NIM enhances the forgetting capability of most GU methods, while
SGU achieves comprehensive SOTA performance and maintains scalability.

**Decision Explanation:** Original decision: REJECT
The paper does not meet the primary criteria as it does not focus on Large Language Models (LLMs) or their applications in areas like knowledge graphs, retrieval-augmented generation (RAG), or agentic AI. Instead, it centers on graph unlearning, machine learning robustness, and data privacy, without apparent connection to LLMs or specified areas of interest.

---

## [Data-driven Detection and Evaluation of Damages in Concrete Structures:
  Using Deep Learning and Computer Vision](https://arxiv.org/abs/2501.11836v1)
**arXiv ID:** 2501.11836v1

**Abstract:**
> Structural integrity is vital for maintaining the safety and longevity of
concrete infrastructures such as bridges, tunnels, and walls. Traditional
methods for detecting damages like cracks and spalls are labor-intensive,
time-consuming, and prone to human error. To address these challenges, this
study explores advanced data-driven techniques using deep learning for
automated damage detection and analysis. Two state-of-the-art instance
segmentation models, YOLO-v7 instance segmentation and Mask R-CNN, were
evaluated using a dataset comprising 400 images, augmented to 10,995 images
through geometric and color-based transformations to enhance robustness. The
models were trained and validated using a dataset split into 90% training set,
validation and test set 10%. Performance metrics such as precision, recall,
mean average precision (mAP@0.5), and frames per second (FPS) were used for
evaluation. YOLO-v7 achieved a superior mAP@0.5 of 96.1% and processed 40 FPS,
outperforming Mask R-CNN, which achieved a mAP@0.5 of 92.1% with a slower
processing speed of 18 FPS. The findings recommend YOLO-v7 instance
segmentation model for real-time, high-speed structural health monitoring,
while Mask R-CNN is better suited for detailed offline assessments. This study
demonstrates the potential of deep learning to revolutionize infrastructure
maintenance, offering a scalable and efficient solution for automated damage
detection.

**Decision Explanation:** Original decision: REJECT
The paper does not meet the primary criteria as it primarily focuses on Computer Vision and Deep Learning for infrastructure maintenance, without any mention of Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, which are the core areas of interest.

---

## [Supervised Learning for Analog and RF Circuit Design: Benchmarks and
  Comparative Insights](https://arxiv.org/abs/2501.11839v1)
**arXiv ID:** 2501.11839v1

**Abstract:**
> Automating analog and radio-frequency (RF) circuit design using machine
learning (ML) significantly reduces the time and effort required for parameter
optimization. This study explores supervised ML-based approaches for designing
circuit parameters from performance specifications across various circuit
types, including homogeneous and heterogeneous designs. By evaluating diverse
ML models, from neural networks like transformers to traditional methods like
random forests, we identify the best-performing models for each circuit. Our
results show that simpler circuits, such as low-noise amplifiers, achieve
exceptional accuracy with mean relative errors as low as 0.3% due to their
linear parameter-performance relationships. In contrast, complex circuits, like
power amplifiers and voltage-controlled oscillators, present challenges due to
their non-linear interactions and larger design spaces. For heterogeneous
circuits, our approach achieves an 88% reduction in errors with increased
training data, with the receiver achieving a mean relative error as low as
0.23%, showcasing the scalability and accuracy of the proposed methodology.
Additionally, we provide insights into model strengths, with transformers
excelling in capturing non-linear mappings and k-nearest neighbors performing
robustly in moderately linear parameter spaces, especially in heterogeneous
circuits with larger datasets. This work establishes a foundation for extending
ML-driven design automation, enabling more efficient and scalable circuit
design workflows.

**Decision Explanation:** Original decision: REJECT
The paper does not meet the primary criteria for Large Language Models (LLMs) applications, instead focusing on machine learning (ML) for analog and RF circuit design, with no apparent connection to LLMs, knowledge graphs, retrieval-augmented generation, or agentic AI.

---

## [Scalable Whole Slide Image Representation Using K-Mean Clustering and
  Fisher Vector Aggregation](https://arxiv.org/abs/2501.12085v1)
**arXiv ID:** 2501.12085v1

**Abstract:**
> Whole slide images (WSIs) are high-resolution, gigapixel sized images that
pose significant computational challenges for traditional machine learning
models due to their size and heterogeneity.In this paper, we present a scalable
and efficient methodology for WSI classification by leveraging patch-based
feature extraction, clustering, and Fisher vector encoding. Initially, WSIs are
divided into fixed size patches, and deep feature embeddings are extracted from
each patch using a pre-trained convolutional neural network (CNN). These
patch-level embeddings are subsequently clustered using K-means clustering,
where each cluster aggregates semantically similar regions of the WSI. To
effectively summarize each cluster, Fisher vector representations are computed
by modeling the distribution of patch embeddings in each cluster as a
parametric Gaussian mixture model (GMM). The Fisher vectors from each cluster
are concatenated into a high-dimensional feature vector, creating a compact and
informative representation of the entire WSI. This feature vector is then used
by a classifier to predict the WSI's diagnostic label. Our method captures
local and global tissue structures and yields robust performance for
large-scale WSI classification, demonstrating superior accuracy and scalability
compared to other approaches.

**Decision Explanation:** Original response: ```
{
    "decision": "REJECT",
    "explanation": "The paper does not meet the primary criteria as it focuses on image processing (Whole Slide Image Representation) and machine learning models (CNN, K-Mean Clustering), with no mention of Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, which are the core areas of interest."
}
```

---

## [Proxies for Distortion and Consistency with Applications for Real-World
  Image Restoration](https://arxiv.org/abs/2501.12102v1)
**arXiv ID:** 2501.12102v1

**Abstract:**
> Real-world image restoration deals with the recovery of images suffering from
an unknown degradation. This task is typically addressed while being given only
degraded images, without their corresponding ground-truth versions. In this
hard setting, designing and evaluating restoration algorithms becomes highly
challenging. This paper offers a suite of tools that can serve both the design
and assessment of real-world image restoration algorithms. Our work starts by
proposing a trained model that predicts the chain of degradations a given
real-world measured input has gone through. We show how this estimator can be
used to approximate the consistency -- the match between the measurements and
any proposed recovered image. We also use this estimator as a guiding force for
the design of a simple and highly-effective plug-and-play real-world image
restoration algorithm, leveraging a pre-trained diffusion-based image prior.
Furthermore, this work proposes no-reference proxy measures of MSE and LPIPS,
which, without access to the ground-truth images, allow ranking of real-world
image restoration algorithms according to their (approximate) MSE and LPIPS.
The proposed suite provides a versatile, first of its kind framework for
evaluating and comparing blind image restoration algorithms in real-world
scenarios.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on image restoration, which falls under video/image processing, one of the excluded areas as per the evaluation criteria. No apparent connection to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI is mentioned in the abstract.

---

## [Efficient PINNs: Multi-Head Unimodular Regularization of the Solutions
  Space](https://arxiv.org/abs/2501.12116v1)
**arXiv ID:** 2501.12116v1

**Abstract:**
> We present a machine learning framework to facilitate the solution of
nonlinear multiscale differential equations and, especially, inverse problems
using Physics-Informed Neural Networks (PINNs). This framework is based on what
is called multihead (MH) training, which involves training the network to learn
a general space of all solutions for a given set of equations with certain
variability, rather than learning a specific solution of the system. This setup
is used with a second novel technique that we call Unimodular Regularization
(UR) of the latent space of solutions. We show that the multihead approach,
combined with the regularization, significantly improves the efficiency of
PINNs by facilitating the transfer learning process thereby enabling the
finding of solutions for nonlinear, coupled, and multiscale differential
equations.

**Decision Explanation:** Original decision: REJECT
The paper does not meet the Practical Applications criterion related to Large Language Models (LLMs), as it focuses on Physics-Informed Neural Networks (PINNs) for solving nonlinear differential equations, without any apparent connection to LLMs, knowledge graphs, RAG, or agentic AI.

---

## [On the practical applicability of modern DFT functionals for chemical
  computations. Case study of DM21 applicability for geometry optimization](https://arxiv.org/abs/2501.12149v1)
**arXiv ID:** 2501.12149v1

**Abstract:**
> Density functional theory (DFT) is probably the most promising approach for
quantum chemistry calculations considering its good balance between
calculations precision and speed. In recent years, several neural network-based
functionals have been developed for exchange-correlation energy approximation
in DFT, DM21 developed by Google Deepmind being the most notable between them.
This study focuses on evaluating the efficiency of DM21 functional in
predicting molecular geometries, with a focus on the influence of oscillatory
behavior in neural network exchange-correlation functionals. We implemented
geometry optimization in PySCF for the DM21 functional in geometry optimization
problem, compared its performance with traditional functionals, and tested it
on various benchmarks. Our findings reveal both the potential and the current
challenges of using neural network functionals for geometry optimization in
DFT. We propose a solution extending the practical applicability of such
functionals and allowing to model new substances with their help.

**Decision Explanation:** Original decision: REJECT
The paper does not meet the required criteria as it primarily focuses on chemical computations using Density Functional Theory (DFT) and neural network-based functionals, with no apparent connection to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI.

---

## [An End-to-End Approach for Korean Wakeword Systems with Speaker
  Authentication](https://arxiv.org/abs/2501.12194v1)
**arXiv ID:** 2501.12194v1

**Abstract:**
> Wakeword detection plays a critical role in enabling AI assistants to listen
to user voices and interact effectively. However, for languages other than
English, there is a significant lack of pre-trained wakeword models.
Additionally, systems that merely determine the presence of a wakeword can pose
serious privacy concerns. In this paper, we propose an end-to-end approach that
trains wakewords for Non-English languages, particulary Korean, and uses this
to develop a Voice Authentication model to protect user privacy. Our
implementation employs an open-source platform OpenWakeWord, which performs
wakeword detection using an FCN (Fully-Connected Network) architecture. Once a
wakeword is detected, our custom-developed code calculates cosine similarity
for robust user authentication. Experimental results demonstrate the
effectiveness of our approach, achieving a 16.79% and a 6.6% Equal Error Rate
(EER) each in the Wakeword Detection and the Voice Authentication. These
findings highlight the model's potential in providing secure and accurate
wakeword detection and authentication for Korean users.

**Decision Explanation:** Original response: ```
{
    "decision": "REJECT",
    "explanation": "The paper primarily focuses on voice processing and speaker authentication, which, while related to AI assistants, does not explicitly involve Large Language Models (LLMs) or their applications in areas like knowledge graphs, RAG, or agentic AI, thus not meeting the core criteria."
}
```

---

## [Strong phonon-mediated high temperature superconductivity in
  Li$_2$AuH$_6$ under ambient pressure](https://arxiv.org/abs/2501.12222v1)
**arXiv ID:** 2501.12222v1

**Abstract:**
> We used our developed AI search engine~(InvDesFlow) to perform extensive
investigations regarding ambient stable superconducting hydrides. A cubic
structure Li$_2$AuH$_6$ with Au-H octahedral motifs is identified to be a
candidate. After performing thermodynamical analysis, we provide a feasible
route to experimentally synthesize this material via the known LiAu and LiH
compounds under ambient pressure. The further first-principles calculations
suggest that Li$_2$AuH$_6$ shows a high superconducting transition temperature
($T_c$) $\sim$ 140 K under ambient pressure. The H-1$s$ electrons strongly
couple with phonon modes of vibrations of Au-H octahedrons as well as
vibrations of Li atoms, where the latter is not taken seriously in other
previously similar cases. Hence, different from previous claims of searching
metallic covalent bonds to find high-$T_c$ superconductors, we emphasize here
the importance of those phonon modes with strong electron-phonon coupling
(EPC). And we suggest that one can intercalate atoms into binary or ternary
hydrides to introduce more potential phonon modes with strong EPC, which is an
effective approach to find high-$T_c$ superconductors within multicomponent
compounds.

**Decision Explanation:** Original decision: REJECT
The paper does not meet any of the required criteria, as it primarily focuses on materials science (superconductivity) with no apparent connection to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation, or agentic AI. The mention of an 'AI search engine' is incidental and not central to the paper's main contribution.

---

## [CBVLM: Training-free Explainable Concept-based Large Vision Language
  Models for Medical Image Classification](https://arxiv.org/abs/2501.12266v1)
**arXiv ID:** 2501.12266v1

**Abstract:**
> The main challenges limiting the adoption of deep learning-based solutions in
medical workflows are the availability of annotated data and the lack of
interpretability of such systems. Concept Bottleneck Models (CBMs) tackle the
latter by constraining the final disease prediction on a set of predefined and
human-interpretable concepts. However, the increased interpretability achieved
through these concept-based explanations implies a higher annotation burden.
Moreover, if a new concept needs to be added, the whole system needs to be
retrained. Inspired by the remarkable performance shown by Large
Vision-Language Models (LVLMs) in few-shot settings, we propose a simple, yet
effective, methodology, CBVLM, which tackles both of the aforementioned
challenges. First, for each concept, we prompt the LVLM to answer if the
concept is present in the input image. Then, we ask the LVLM to classify the
image based on the previous concept predictions. Moreover, in both stages, we
incorporate a retrieval module responsible for selecting the best examples for
in-context learning. By grounding the final diagnosis on the predicted
concepts, we ensure explainability, and by leveraging the few-shot capabilities
of LVLMs, we drastically lower the annotation cost. We validate our approach
with extensive experiments across four medical datasets and twelve LVLMs (both
generic and medical) and show that CBVLM consistently outperforms CBMs and
task-specific supervised methods without requiring any training and using just
a few annotated examples. More information on our project page:
https://cristianopatricio.github.io/CBVLM/.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on medical applications of AI, which is explicitly listed as a criterion for rejection, outweighing its potential alignment with other criteria such as practical applications, experimental results, and novelty.

---

## [Implementation of an Asymmetric Adjusted Activation Function for Class
  Imbalance Credit Scoring](https://arxiv.org/abs/2501.12285v1)
**arXiv ID:** 2501.12285v1

**Abstract:**
> Credit scoring is a systematic approach to evaluate a borrower's probability
of default (PD) on a bank loan. The data associated with such scenarios are
characteristically imbalanced, complicating binary classification owing to the
often-underestimated cost of misclassification during the classifier's learning
process. Considering the high imbalance ratio (IR) of these datasets, we
introduce an innovative yet straightforward optimized activation function by
incorporating an IR-dependent asymmetric adjusted factor embedded Sigmoid
activation function (ASIG). The embedding of ASIG makes the sensitive margin of
the Sigmoid function auto-adjustable, depending on the imbalance nature of the
datasets distributed, thereby giving the activation function an asymmetric
characteristic that prevents the underrepresentation of the minority class
(positive samples) during the classifier's learning process. The experimental
results show that the ASIG-embedded-classifier outperforms traditional
classifiers on datasets across wide-ranging IRs in the downstream
credit-scoring task. The algorithm also shows robustness and stability, even
when the IR is ultra-high. Therefore, the algorithm provides a competitive
alternative in the financial industry, especially in credit scoring, possessing
the ability to effectively process highly imbalanced distribution data.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on a financial application (credit scoring) with no evident connection to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, failing to meet the essential criteria for practical applications of LLMs.

---

## [Regressor-Guided Image Editing Regulates Emotional Response to Reduce
  Online Engagement](https://arxiv.org/abs/2501.12289v1)
**arXiv ID:** 2501.12289v1

**Abstract:**
> Emotions are known to mediate the relationship between users' content
consumption and their online engagement, with heightened emotional intensity
leading to increased engagement. Building on this insight, we propose three
regressor-guided image editing approaches aimed at diminishing the emotional
impact of images. These include (i) a parameter optimization approach based on
global image transformations known to influence emotions, (ii) an optimization
approach targeting the style latent space of a generative adversarial network,
and (iii) a diffusion-based approach employing classifier guidance and
classifier-free guidance. Our findings demonstrate that approaches can
effectively alter the emotional properties of images while maintaining high
visual quality. Optimization-based methods primarily adjust low-level
properties like color hues and brightness, whereas the diffusion-based approach
introduces semantic changes, such as altering appearance or facial expressions.
Notably, results from a behavioral study reveal that only the diffusion-based
approach successfully elicits changes in viewers' emotional responses while
preserving high perceived image quality. In future work, we will investigate
the impact of these image adaptations on internet user behavior.

**Decision Explanation:** Original response: ```
{
    "decision": "REJECT",
    "explanation": "The paper primarily focuses on image processing and emotional response regulation, which aligns with video/image processing, and does not evidently involve Large Language Models (LLMs) or related areas like knowledge graphs, RAG, or agentic AI, failing to meet the required criteria."
}
```

---

## [DARB-Splatting: Generalizing Splatting with Decaying Anisotropic Radial
  Basis Functions](https://arxiv.org/abs/2501.12369v1)
**arXiv ID:** 2501.12369v1

**Abstract:**
> Splatting-based 3D reconstruction methods have gained popularity with the
advent of 3D Gaussian Splatting, efficiently synthesizing high-quality novel
views. These methods commonly resort to using exponential family functions,
such as the Gaussian function, as reconstruction kernels due to their
anisotropic nature, ease of projection, and differentiability in rasterization.
However, the field remains restricted to variations within the exponential
family, leaving generalized reconstruction kernels largely underexplored,
partly due to the lack of easy integrability in 3D to 2D projections. In this
light, we show that a class of decaying anisotropic radial basis functions
(DARBFs), which are non-negative functions of the Mahalanobis distance,
supports splatting by approximating the Gaussian function's closed-form
integration advantage. With this fresh perspective, we demonstrate up to 34%
faster convergence during training and a 15% reduction in memory consumption
across various DARB reconstruction kernels, while maintaining comparable PSNR,
SSIM, and LPIPS results. We will make the code available.

**Decision Explanation:** Original response: ```
{
    "decision": "REJECT",
    "explanation": "The paper primarily focuses on 3D reconstruction and splatting with radial basis functions, which falls under video/image processing, and does not involve Large Language Models (LLMs) or related areas specified in the criteria."
}

---

## [Expertise elevates AI usage: experimental evidence comparing laypeople
  and professional artists](https://arxiv.org/abs/2501.12374v1)
**arXiv ID:** 2501.12374v1

**Abstract:**
> Novel capacities of generative AI to analyze and generate cultural artifacts
raise inevitable questions about the nature and value of artistic education and
human expertise. Has AI already leveled the playing field between professional
artists and laypeople, or do trained artistic expressive capacity, curation
skills and experience instead enhance the ability to use these new tools? In
this pre-registered study, we conduct experimental comparisons between 50
active artists and a demographically matched sample of laypeople. We designed
two tasks to approximate artistic practice for testing their capabilities in
both faithful and creative image creation: replicating a reference image, and
moving as far away as possible from it. We developed a bespoke platform where
participants used a modern text-to-image model to complete both tasks. We also
collected and compared participants' sentiments towards AI. On average, artists
produced more faithful and creative outputs than their lay counterparts,
although only by a small margin. While AI may ease content creation,
professional expertise is still valuable - even within the confined space of
generative AI itself. Finally, we also explored how well an exemplary
vision-capable large language model (GPT-4o) would complete the same tasks, if
given the role of an image generation agent, and found it performed on par in
copying but outperformed even artists in the creative task. The very best
results were still produced by humans in both tasks. These outcomes highlight
the importance of integrating artistic skills with AI training to prepare
artists and other visual professionals for a technologically evolving
landscape. We see a potential in collaborative synergy with generative AI,
which could reshape creative industries and education in the arts.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on the intersection of AI and artistic education, which aligns with 'social applications of AI' (regarding education and human expertise) and does not clearly meet the required criteria for Large Language Models (LLMs) in areas like knowledge graphs, retrieval-augmented generation, or agentic AI, beyond a tangential mention.

---

## [MMVU: Measuring Expert-Level Multi-Discipline Video Understanding](https://arxiv.org/abs/2501.12380v1)
**arXiv ID:** 2501.12380v1

**Abstract:**
> We introduce MMVU, a comprehensive expert-level, multi-discipline benchmark
for evaluating foundation models in video understanding. MMVU includes 3,000
expert-annotated questions spanning 27 subjects across four core disciplines:
Science, Healthcare, Humanities & Social Sciences, and Engineering. Compared to
prior benchmarks, MMVU features three key advancements. First, it challenges
models to apply domain-specific knowledge and perform expert-level reasoning to
analyze specialized-domain videos, moving beyond the basic visual perception
typically assessed in current video benchmarks. Second, each example is
annotated by human experts from scratch. We implement strict data quality
controls to ensure the high quality of the dataset. Finally, each example is
enriched with expert-annotated reasoning rationals and relevant domain
knowledge, facilitating in-depth analysis. We conduct an extensive evaluation
of 32 frontier multimodal foundation models on MMVU. The latest
System-2-capable models, o1 and Gemini 2.0 Flash Thinking, achieve the highest
performance among the tested models. However, they still fall short of matching
human expertise. Through in-depth error analyses and case studies, we offer
actionable insights for future advancements in expert-level,
knowledge-intensive video understanding for specialized domains.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on video processing and understanding, which is explicitly listed as a criterion for rejection. While it mentions foundation models and knowledge-intensive tasks, the core application is video-centric, outweighing potential marginal relevance to Large Language Models (LLMs) in other areas.

---

## [Physics of Skill Learning](https://arxiv.org/abs/2501.12391v1)
**arXiv ID:** 2501.12391v1

**Abstract:**
> We aim to understand physics of skill learning, i.e., how skills are learned
in neural networks during training. We start by observing the Domino effect,
i.e., skills are learned sequentially, and notably, some skills kick off
learning right after others complete learning, similar to the sequential fall
of domino cards. To understand the Domino effect and relevant behaviors of
skill learning, we take physicists' approach of abstraction and simplification.
We propose three models with varying complexities -- the Geometry model, the
Resource model, and the Domino model, trading between reality and simplicity.
The Domino effect can be reproduced in the Geometry model, whose resource
interpretation inspires the Resource model, which can be further simplified to
the Domino model. These models present different levels of abstraction and
simplification; each is useful to study some aspects of skill learning. The
Geometry model provides interesting insights into neural scaling laws and
optimizers; the Resource model sheds light on the learning dynamics of
compositional tasks; the Domino model reveals the benefits of modularity. These
models are not only conceptually interesting -- e.g., we show how Chinchilla
scaling laws can emerge from the Geometry model, but also are useful in
practice by inspiring algorithmic development -- e.g., we show how simple
algorithmic changes, motivated by these toy models, can speed up the training
of deep learning models.

**Decision Explanation:** Original decision: REJECT
The paper 'Physics of Skill Learning' does not meet the required criteria as it primarily focuses on understanding skill learning in neural networks, without mentioning Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, and does not demonstrate direct practical applications or comparisons with state-of-the-art LLM techniques.

---

## [Learning segmentation from point trajectories](https://arxiv.org/abs/2501.12392v1)
**arXiv ID:** 2501.12392v1

**Abstract:**
> We consider the problem of segmenting objects in videos based on their motion
and no other forms of supervision. Prior work has often approached this problem
by using the principle of common fate, namely the fact that the motion of
points that belong to the same object is strongly correlated. However, most
authors have only considered instantaneous motion from optical flow. In this
work, we present a way to train a segmentation network using long-term point
trajectories as a supervisory signal to complement optical flow. The key
difficulty is that long-term motion, unlike instantaneous motion, is difficult
to model -- any parametric approximation is unlikely to capture complex motion
patterns over long periods of time. We instead draw inspiration from subspace
clustering approaches, proposing a loss function that seeks to group the
trajectories into low-rank matrices where the motion of object points can be
approximately explained as a linear combination of other point tracks. Our
method outperforms the prior art on motion-based segmentation, which shows the
utility of long-term motion and the effectiveness of our formulation.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on video processing, which is explicitly listed as a rejection criterion. Additionally, there is no apparent connection to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI, which are the core areas of interest.

---

## [Unsupervised Learning in Echo State Networks for Input Reconstruction](https://arxiv.org/abs/2501.11409v1)
**arXiv ID:** 2501.11409v1

**Abstract:**
> Conventional echo state networks (ESNs) require supervised learning to train
the readout layer, using the desired outputs as training data. In this study,
we focus on input reconstruction (IR), which refers to training the readout
layer to reproduce the input time series in its output. We reformulate the
learning algorithm of the ESN readout layer to perform IR using unsupervised
learning (UL). By conducting theoretical analysis and numerical experiments, we
demonstrate that IR in ESNs can be effectively implemented under realistic
conditions without explicitly using the desired outputs as training data; in
this way, UL is enabled. Furthermore, we demonstrate that applications relying
on IR, such as dynamical system replication and noise filtering, can be
reformulated within the UL framework. Our findings establish a theoretically
sound and universally applicable IR formulation, along with its related tasks
in ESNs. This work paves the way for novel predictions and highlights
unresolved theoretical challenges in ESNs, particularly in the context of
time-series processing methods and computational models of the brain.

**Decision Explanation:** Original decision: REJECT
The paper does not meet any of the required criteria, as it focuses on unsupervised learning in Echo State Networks (ESNs) for input reconstruction, without mentioning Large Language Models (LLMs), practical applications related to LLMs, or relevant experimental results with quantitative metrics. It also doesn't meet any of the additional criteria relevant to LLMs.

---

## [Improving thermal state preparation of Sachdev-Ye-Kitaev model with
  reinforcement learning on quantum hardware](https://arxiv.org/abs/2501.11454v1)
**arXiv ID:** 2501.11454v1

**Abstract:**
> The Sachdev-Ye-Kitaev (SYK) model, known for its strong quantum correlations
and chaotic behavior, serves as a key platform for quantum gravity studies.
However, variationally preparing thermal states on near-term quantum processors
for large systems (N>12, where N is the number of Majorana fermions) presents a
significant challenge due to the rapid growth in the complexity of
parameterized quantum circuits. This paper addresses this challenge by
integrating reinforcement learning (RL) with convolutional neural networks,
employing an iterative approach to optimize the quantum circuit and its
parameters. The refinement process is guided by a composite reward signal
derived from entropy and the expectation values of the SYK Hamiltonian. This
approach reduces the number of CNOT gates by two orders of magnitude for
systems N>10 compared to traditional methods like first-order Trotterization.
We demonstrate the effectiveness of the RL framework in both noiseless and
noisy quantum hardware environments, maintaining high accuracy in thermal state
preparation. This work contributes to the advancement of a scalable, RL-based
framework with applications for computations of thermal out-of-time-order
correlators in quantum many-body systems and quantum gravity studies on
near-term quantum hardware.

**Decision Explanation:** Original decision: REJECT
The paper does not meet the criteria as it primarily focuses on quantum computing and reinforcement learning for thermal state preparation, with no apparent connection to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation, or agentic AI.

---

## [With Great Backbones Comes Great Adversarial Transferability](https://arxiv.org/abs/2501.12275v1)
**arXiv ID:** 2501.12275v1

**Abstract:**
> Advances in self-supervised learning (SSL) for machine vision have improved
representation robustness and model performance, giving rise to pre-trained
backbones like \emph{ResNet} and \emph{ViT} models tuned with SSL methods such
as \emph{SimCLR}. Due to the computational and data demands of pre-training,
the utilization of such backbones becomes a strenuous necessity. However,
employing these backbones may inherit vulnerabilities to adversarial attacks.
While adversarial robustness has been studied under \emph{white-box} and
\emph{black-box} settings, the robustness of models tuned on pre-trained
backbones remains largely unexplored. Additionally, the role of tuning
meta-information in mitigating exploitation risks is unclear. This work
systematically evaluates the adversarial robustness of such models across
$20,000$ combinations of tuning meta-information, including fine-tuning
techniques, backbone families, datasets, and attack types. We propose using
proxy models to transfer attacks, simulating varying levels of target knowledge
by fine-tuning these proxies with diverse configurations. Our findings reveal
that proxy-based attacks approach the effectiveness of \emph{white-box}
methods, even with minimal tuning knowledge. We also introduce a naive
"backbone attack," leveraging only the backbone to generate adversarial
samples, which outperforms \emph{black-box} attacks and rivals \emph{white-box}
methods, highlighting critical risks in model-sharing practices. Finally, our
ablations reveal how increasing tuning meta-information impacts attack
transferability, measuring each meta-information combination.

**Decision Explanation:** Original decision: REJECT
The paper primarily focuses on adversarial attacks and robustness in machine vision (computer vision) with self-supervised learning, which does not meet the criteria of focusing on Large Language Models (LLMs) or their applications in areas like knowledge graphs, retrieval-augmented generation (RAG), or agentic AI. The topic aligns more with video/image processing, which is explicitly listed as a reason for rejection.

---

## [Goal-oriented Transmission Scheduling: Structure-guided DRL with a
  Unified Dual On-policy and Off-policy Approach](https://arxiv.org/abs/2501.11921v1)
**arXiv ID:** 2501.11921v1

**Abstract:**
> Goal-oriented communications prioritize application-driven objectives over
data accuracy, enabling intelligent next-generation wireless systems. Efficient
scheduling in multi-device, multi-channel systems poses significant challenges
due to high-dimensional state and action spaces. We address these challenges by
deriving key structural properties of the optimal solution to the goal-oriented
scheduling problem, incorporating Age of Information (AoI) and channel states.
Specifically, we establish the monotonicity of the optimal state value function
(a measure of long-term system performance) w.r.t. channel states and prove its
asymptotic convexity w.r.t. AoI states. Additionally, we derive the
monotonicity of the optimal policy w.r.t. channel states, advancing the
theoretical framework for optimal scheduling. Leveraging these insights, we
propose the structure-guided unified dual on-off policy DRL (SUDO-DRL), a
hybrid algorithm that combines the stability of on-policy training with the
sample efficiency of off-policy methods. Through a novel structural property
evaluation framework, SUDO-DRL enables effective and scalable training,
addressing the complexities of large-scale systems. Numerical results show
SUDO-DRL improves system performance by up to 45% and reduces convergence time
by 40% compared to state-of-the-art methods. It also effectively handles
scheduling in much larger systems, where off-policy DRL fails and on-policy
benchmarks exhibit significant performance loss, demonstrating its scalability
and efficacy in goal-oriented communications.

**Decision Explanation:** Original decision: REJECT
The paper does not meet any of the required criteria (1-3) as it focuses on Goal-oriented Transmission Scheduling in wireless systems using Deep Reinforcement Learning (DRL), with no apparent connection to Large Language Models (LLMs), knowledge graphs, retrieval-augmented generation (RAG), or agentic AI.

---

